Attribute VB_Name = "CMQB"
Option Explicit
'**********************************************************************'
'*                                                                    *'
'*  Program name:  CMQB                                               *'
'*                                                                    *'
'*  Description:   This file declares calls, structures, and          *'
'*                 constants for the IBM Message Queue Interface      *'
'*                 (MQI) in the Windows Visual Basic V4.0             *'
'*                 environment (both 16-bit and 32-bit), and the      *'
'*                 Visual Basic 5.0 environment (32-bit).             *'
'*                 Detection of the environment is automatic          *'
'*                 based on the Win16/Win32 builtin conditional       *'
'*                 compiler constant.                                 *'
'*                                                                    *'
'*                 CMQB will run against either the MQSeries server   *'
'*                 or the MQSeries client depending on the            *'
'*                 conditional compilation argument MqType            *'
'*                 To set MqType in Visual Basic 4.0:                 *'
'*                   Select the menu option "Tools - Options..."      *'
'*                   On the tab labelled "Advanced", edit the field   *'
'*                   "Conditional Compilation"                        *'
'*                 To set MqType in Visual Basic 5.0:                 *'
'*                   Select the menu option "Project - xx Properties" *'
'*                     (where xx is the name of the project)          *'
'*                   On the tab labelled "Make", edit the field       *'
'*                   "Conditional Compilation"                        *'
'*                                                                    *'
'*                 In the Conditional Compiliation field              *'
'*                 enter (without the quotes):                        *'
'*                   "MqType = 1" for the MQSeries server             *'
'*                   "MqType = 2" for the MQSeries client             *'
'*                                                                    *'
'*                 The selection of 16/32 bit and client/server       *'
'*                 controlls the selection of MQSeries DLL.           *'
'*                 The appropriate DLL must be installed on           *'
'*                 and the queue manager running for the Visual Basic *'
'*                 application to operate correctly.                  *'
'*                                                                    *'
'*                 To ensure that various default constants are setup *'
'*                 properly, the procedure MQ_SETDEFAULTS should be   *'
'*                 called before any other MQSeries calls. A good     *'
'*                 place to put this call is in the Load procedure of *'
'*                 the startup form. See the sample programs for an   *'
'*                 example.                                           *'
'*                                                                    *'
'* COMMON PROBLEMS:                                                   *'
'*                                                                    *'
'* ================================================                   *'
'*   Visual Basic error:                                              *'
'* ================================================                   *'
'*     Run-time error '48'                                            *'
'*     Error in loading DLL                                           *'
'*                                                                    *'
'*     Run-time error '53'                                            *'
'*     File not found                                                 *'
'*                                                                    *'
'* PROBLEM:                                                           *'
'*   Incorrect Mqtype= setting                                        *'
'*                                                                    *'
'* SOLUTION:                                                          *'
'*  Change MqType setting - see comments above                        *'
'*                                                                    *'
'* ================================================                   *'
'*   Run-time error: CompCode = 2, Reason = 2059                      *'
'* ================================================                   *'
'*                                                                    *'
'* PROBLEM:                                                           *'
'*   MQRC_Q_MGR_NOT_AVAILABLE                                         *'
'*   Queue Manager not available                                      *'
'*                                                                    *'
'* SOLUTION:                                                          *'
'*   Check MQSERVER environment variable                              *'
'*     Under Windows NT 4                                             *'
'*       Click: Start->Settings->Control Panel                        *'
'*       Double Click: System                                         *'
'*       Click tab for ENVIRONMENT                                    *'
'*       Add/Change System variable:                                  *'
'*         MQSERVER=channel_name/tcp/tcp_name                         *'
'*     Under Windows 3.1 or Windows 95                                *'
'*       Edit AUTOEXEC.BAT file                                       *'
'*       Add the line:                                                *'
'*       SET MQSERVER=channel_name/tcp/tcp_name                       *'
'*     Note: channel_name is case sensitive                           *'
'*                                                                    *'
'*  For Windows 3.1/95/98 Check:                                      *'
'*    \MQM\MQS.INI has an entry:                                      *'
'*      AllQueueManagers:                                             *'
'*        DefaultPrefix=D:\mqm                                        *'
'*        D: is disk where MQClient is installed                      *'
'*    If necessary, rerun REGISTER.EXE from D:\MQM directory          *'
'*                                                                    *'
'*    The above MQS.INI is not relevant for NT.                       *'
'*                                                                    *'
'*  Verify that the server can be "ping"ed                            *'
'*    ping tcp_name                                                   *'
'*                                                                    *'
'*  Verify C samples work:                                            *'
'*    \MQM\TOOLS\SAMPLES\C\BIN\AMQSPUTC.EXE                           *'
'*    \MQM\TOOLS\SAMPLES\C\BIN\AMQSGETC.EXE                           *'
'*                                                                    *'
'*  Statement:     Licensed Materials - Property of IBM               *'
'*                 (C) Copyright IBM Corp. 1994, 1999                 *'
'*  Status:        Version 5 Release 1                                *'
'*                                                                    *'
'*                 04L1830, 5639-B43                                  *'
'*                                                                    *'
'*                 U.S. Government Users Restricted Rights -          *'
'*                 use, duplication or disclosure restricted by       *'
'*                 GSA ADP Schedule Contract with IBM Corp.           *'
'*                                                                    *'
'**********************************************************************'

'**********************************************************************'
'*  Values related to MQBO Structure                                  *'
'**********************************************************************'
' Structure identifier
Global Const MQBO_STRUC_ID = "BO  "

' Structure Version Number
Global Const MQBO_VERSION_1 = 1
Global Const MQBO_CURRENT_VERSION = 1

' Begin Options
Global Const MQBO_NONE = 0

 '*********************************************************************'
 '*  Values Related to MQCIH Structure                                *'
 '*********************************************************************'

 '* Structure Identifier *'
 Global Const MQCIH_STRUC_ID = "CIH "

 '* Structure Version Number *'
 Global Const MQCIH_VERSION_1 = 1
 Global Const MQCIH_VERSION_2 = 2
 Global Const MQCIH_CURRENT_VERSION = 2

 '* Structure Length *'
 Global Const MQCIH_LENGTH_1 = 164
 Global Const MQCIH_LENGTH_2 = 180
 Global Const MQCIH_CURRENT_LENGTH = 180

 '* Flags *'
 Global Const MQCIH_NONE = 0

 '* Return Code *'
 Global Const MQCRC_OK = 0
 Global Const MQCRC_CICS_EXEC_ERROR = 1
 Global Const MQCRC_MQ_API_ERROR = 2
 Global Const MQCRC_BRIDGE_ERROR = 3
 Global Const MQCRC_BRIDGE_ABEND = 4
 Global Const MQCRC_APPLICATION_ABEND = 5
 Global Const MQCRC_SECURITY_ERROR = 6
 Global Const MQCRC_PROGRAM_NOT_AVAILABLE = 7
 Global Const MQCRC_BRIDGE_TIMEOUT = 8
 Global Const MQCRC_TRANSID_NOT_AVAILABLE = 9

 '* Unit of Work Control *'
 Global Const MQCUOWC_ONLY = 273
 Global Const MQCUOWC_CONTINUE = 65536
 Global Const MQCUOWC_FIRST = 17
 Global Const MQCUOWC_MIDDLE = 16
 Global Const MQCUOWC_LAST = 272
 Global Const MQCUOWC_COMMIT = 256
 Global Const MQCUOWC_BACKOUT = 4352

 '* Get Wait Interval *'
 Global Const MQCGWI_DEFAULT = -2

 '* Link Type *'
 Global Const MQCLT_PROGRAM = 1
 Global Const MQCLT_TRANSACTION = 2

 '* Output Data Length *'
 Global Const MQCODL_AS_INPUT = -1

 '* ADS Descriptor *'
 Global Const MQCADSD_NONE = 0
 Global Const MQCADSD_SEND = 1
 Global Const MQCADSD_RECV = 16
 Global Const MQCADSD_MSGFORMAT = 256

 '* Conversational Task *'
 Global Const MQCCT_YES = 1
 Global Const MQCCT_NO = 0

 '* Task End Status *'
 Global Const MQCTES_NOSYNC = 0
 Global Const MQCTES_COMMIT = 256
 Global Const MQCTES_BACKOUT = 4352
 Global Const MQCTES_ENDTASK = 65536

 '* Facility *'
 Public MQCFAC_NONE As String * 8  'must initialise with MQSET_DEFAULTS call
 
 '* Function *'
 Global Const MQCFUNC_MQCONN = "CONN"
 Global Const MQCFUNC_MQGET = "GET "
 Global Const MQCFUNC_MQINQ = "INQ "
 Global Const MQCFUNC_MQOPEN = "OPEN"
 Global Const MQCFUNC_MQPUT = "PUT "
 Global Const MQCFUNC_MQPUT1 = "PUT1"
 Global Const MQCFUNC_NONE = "    "

 '* Start Code *'
 Global Const MQCSC_START = "S   "
 Global Const MQCSC_STARTDATA = "SD  "
 Global Const MQCSC_TERMINPUT = "TD  "
 Global Const MQCSC_NONE = "    "

'**********************************************************************'
'*  Values Related to MQCNO Structure                                 *'
'**********************************************************************'
' Structure Identifier
Global Const MQCNO_STRUC_ID = "CNO "

' Structure Version Number
Global Const MQCNO_VERSION_1 = 1
Global Const MQCNO_VERSION_2 = 2
Global Const MQCNO_CURRENT_VERSION = 2

' Connect Options
Global Const MQCNO_STANDARD_BINDING = 0
Global Const MQCNO_FASTPATH_BINDING = 1
Global Const MQCNO_HANDLE_SHARE_NONE = 0
Global Const MQCNO_HANDLE_SHARE_SERIAL = 2
Global Const MQCNO_NONE = 0

'**********************************************************************'
'*  Values Related to MQDH Structure                                  *'
'**********************************************************************'

'Structure identifier
Global Const MQDH_STRUC_ID = "DH  "

'Structure version number
Global Const MQDH_VERSION_1 = 1
Global Const MQDH_CURRENT_VERSION = 1

'General Flags
Global Const MQDHF_NEW_MSG_IDS = 1
Global Const MQDHF_NONE = 0

'* Put Message Record Flags *'
'* See values for "Put Message Record Fields" under MQPMO *'
 
'**********************************************************************'
'*  Values Related to MQDLH Structure                                 *'
'**********************************************************************'

'Structure Identifier
Global Const MQDLH_STRUC_ID = "DLH "

'Structure Version Number
Global Const MQDLH_VERSION_1 = 1
Global Const MQDLH_CURRENT_VERSION = 1

'**********************************************************************'
'*  Values Related to MQGMO Structure                                 *'
'**********************************************************************'

' Structure Identifier
Global Const MQGMO_STRUC_ID = "GMO "

' Structure Version Number
Global Const MQGMO_VERSION_1 = 1
Global Const MQGMO_VERSION_2 = 2
Global Const MQGMO_VERSION_3 = 3
Global Const MQGMO_CURRENT_VERSION = 3

' Get-Message Options
Global Const MQGMO_WAIT = 1
Global Const MQGMO_NO_WAIT = 0
Global Const MQGMO_SYNCPOINT = 2
Global Const MQGMO_SYNCPOINT_IF_PERSISTENT = 4096
Global Const MQGMO_NO_SYNCPOINT = 4
Global Const MQGMO_MARK_SKIP_BACKOUT = 128
Global Const MQGMO_BROWSE_FIRST = 16
Global Const MQGMO_BROWSE_NEXT = 32
Global Const MQGMO_BROWSE_MSG_UNDER_CURSOR = 2048
Global Const MQGMO_MSG_UNDER_CURSOR = 256
Global Const MQGMO_LOCK = 512
Global Const MQGMO_UNLOCK = 1024
Global Const MQGMO_ACCEPT_TRUNCATED_MSG = 64
Global Const MQGMO_SET_SIGNAL = 8
Global Const MQGMO_FAIL_IF_QUIESCING = 8192
Global Const MQGMO_CONVERT = 16384
Global Const MQGMO_LOGICAL_ORDER = 32768
Global Const MQGMO_COMPLETE_MSG = 65536
Global Const MQGMO_ALL_MSGS_AVAILABLE = 131072
Global Const MQGMO_ALL_SEGMENTS_AVAILABLE = 262144
Global Const MQGMO_NONE = 0

' Wait Interval
Global Const MQWI_UNLIMITED = -1

' Signal Values
Global Const MQEC_MSG_ARRIVED = 2
Global Const MQEC_WAIT_INTERVAL_EXPIRED = 3
Global Const MQEC_WAIT_CANCELED = 4
Global Const MQEC_Q_MGR_QUIESCING = 5
Global Const MQEC_CONNECTION_QUIESCING = 6

' Match Options
Global Const MQMO_MATCH_MSG_ID = 1
Global Const MQMO_MATCH_CORREL_ID = 2
Global Const MQMO_MATCH_GROUP_ID = 4
Global Const MQMO_MATCH_MSG_SEQ_NUMBER = 8
Global Const MQMO_MATCH_OFFSET = 16
Global Const MQMO_MATCH_MSG_TOKEN = 32
Global Const MQMO_NONE = 0

' Group Status
Global Const MQGS_NOT_IN_GROUP = " "
Global Const MQGS_MSG_IN_GROUP = "G"
Global Const MQGS_LAST_MSG_IN_GROUP = "L"

' Segment Status
Global Const MQSS_NOT_A_SEGMENT = " "
Global Const MQSS_SEGMENT = "S"
Global Const MQSS_LAST_SEGMENT = "L"

' Segmentation
Global Const MQSEG_INHIBITED = " "
Global Const MQSEG_ALLOWED = "A"

' Message Token
Public MQMTOK_NONE As String * 16   'must initialise with MQSET_DEFAULTS call

' Returned Length
Global Const MQRL_UNDEFINED = -1

'**********************************************************************'
'*  Values Related to MQIIH Structure                                 *'
'**********************************************************************'
' Structure Identifier
Global Const MQIIH_STRUC_ID = "IIH "

' Structure Version
Global Const MQIIH_VERSION_1 = 1
Global Const MQIIH_CURRENT_VERSION = 1

' Header Length
Global Const MQIIH_LENGTH_1 = 84

'Flags
Global Const MQIIH_NONE = 0

'Authenticator
Global Const MQIAUT_NONE = "        "

' Transaction Instance Identifier
Public MQITII_NONE As String * 16   'must initialise with MQSET_DEFAULTS call


' Transaction State
Global Const MQITS_IN_CONVERSATION = "C"
Global Const MQITS_NOT_IN_CONVERSATION = " "

' Commit Mode
Global Const MQICM_COMMIT_THEN_SEND = "0"
Global Const MQICM_SEND_THEN_COMMIT = "1"

' Security Scope
Global Const MQISS_CHECK = "C"
Global Const MQISS_FULL = "F"

'**********************************************************************'
'*  Values Related to MQMD Structure                                  *'
'**********************************************************************'

'Structure Identifier'
Global Const MQMD_STRUC_ID = "MD  "

'Structure Version Number'
Global Const MQMD_VERSION_1 = 1
Global Const MQMD_VERSION_2 = 2
Global Const MQMD_CURRENT_VERSION = 2

'Report Options'
Global Const MQRO_EXCEPTION = &H1000000
Global Const MQRO_EXCEPTION_WITH_DATA = &H3000000
Global Const MQRO_EXCEPTION_WITH_FULL_DATA = &H7000000
Global Const MQRO_EXPIRATION = &H200000
Global Const MQRO_EXPIRATION_WITH_DATA = &H600000
Global Const MQRO_EXPIRATION_WITH_FULL_DATA = &HE00000
Global Const MQRO_COA = &H100
Global Const MQRO_COA_WITH_DATA = &H300
Global Const MQRO_COA_WITH_FULL_DATA = &H700
Global Const MQRO_COD = &H800
Global Const MQRO_COD_WITH_DATA = &H1800
Global Const MQRO_COD_WITH_FULL_DATA = &H3800
Global Const MQRO_PAN = &H1
Global Const MQRO_NAN = &H2
Global Const MQRO_NEW_MSG_ID = &H0
Global Const MQRO_PASS_MSG_ID = &H80
Global Const MQRO_COPY_MSG_ID_TO_CORREL_ID = &H0
Global Const MQRO_PASS_CORREL_ID = &H40
Global Const MQRO_DEAD_LETTER_Q = &H0
Global Const MQRO_DISCARD_MSG = &H8000000
Global Const MQRO_DISCARD_ON_ARRIVAL = &H10000000
Global Const MQRO_COM = &H4000
Global Const MQRO_NONE = &H0

' Report Options Masks
Global Const MQRO_REJECT_UNSUP_MASK = &H101C0000
Global Const MQRO_ACCEPT_UNSUP_MASK = &HEFE000FF
Global Const MQRO_ACCEPT_UNSUP_IF_XMIT_MASK = &H3FF00

' Message Types
Global Const MQMT_SYSTEM_FIRST = 1
Global Const MQMT_REQUEST = 1
Global Const MQMT_REPLY = 2
Global Const MQMT_DATAGRAM = 8
Global Const MQMT_REPORT = 4
Global Const MQMT_SYSTEM_LAST = 65535
Global Const MQMT_APPL_FIRST = 65536
Global Const MQMT_APPL_LAST = 999999999

'Expiry'
Global Const MQEI_UNLIMITED = -1

'Feedback Values'
Global Const MQFB_NONE = 0
Global Const MQFB_SYSTEM_FIRST = 1
Global Const MQFB_QUIT = 256
Global Const MQFB_EXPIRATION = 258
Global Const MQFB_COA = 259
Global Const MQFB_COD = 260
Global Const MQFB_COM = 261
Global Const MQFB_PAN = 275
Global Const MQFB_NAN = 276
Global Const MQFB_CHANNEL_COMPLETED = 262
Global Const MQFB_CHANNEL_FAIL_RETRY = 263
Global Const MQFB_CHANNEL_FAIL = 264
Global Const MQFB_APPL_CANNOT_BE_STARTED = 265
Global Const MQFB_TM_ERROR = 266
Global Const MQFB_APPL_TYPE_ERROR = 267
Global Const MQFB_STOPPED_BY_MSG_EXIT = 268
Global Const MQFB_XMIT_Q_MSG_ERROR = 271
Global Const MQFB_STOPPED_BY_CHAD_EXIT = 277
Global Const MQFB_STOPPED_BY_PUBSUB_EXIT = 279
Global Const MQFB_DATA_LENGTH_ZERO = 291
Global Const MQFB_DATA_LENGTH_NEGATIVE = 292
Global Const MQFB_DATA_LENGTH_TOO_BIG = 293
Global Const MQFB_BUFFER_OVERFLOW = 294
Global Const MQFB_LENGTH_OFF_BY_ONE = 295
Global Const MQFB_IIH_ERROR = 296
Global Const MQFB_NOT_AUTHORIZED_FOR_IMS = 298
Global Const MQFB_IMS_ERROR = 300
Global Const MQFB_IMS_FIRST = 301
Global Const MQFB_IMS_LAST = 399

Global Const MQFB_CICS_INTERNAL_ERROR = 401
Global Const MQFB_CICS_NOT_AUTHORIZED = 402
Global Const MQFB_CICS_BRIDGE_FAILURE = 403
Global Const MQFB_CICS_CORREL_ID_ERROR = 404
Global Const MQFB_CICS_CCSID_ERROR = 405
Global Const MQFB_CICS_ENCODING_ERROR = 406
Global Const MQFB_CICS_CIH_ERROR = 407
Global Const MQFB_CICS_UOW_ERROR = 408
Global Const MQFB_CICS_COMMAREA_ERROR = 409
Global Const MQFB_CICS_APPL_NOT_STARTED = 410
Global Const MQFB_CICS_APPL_ABENDED = 411
Global Const MQFB_CICS_DLQ_ERROR = 412
Global Const MQFB_CICS_UOW_BACKED_OUT = 413
Global Const MQFB_SYSTEM_LAST = 65535
Global Const MQFB_APPL_FIRST = 65536
Global Const MQFB_APPL_LAST = 999999999

'Encoding'
Global Const MQENC_NATIVE = &H222

' Encoding Masks
Global Const MQENC_INTEGER_MASK = &HF
Global Const MQENC_DECIMAL_MASK = &HF0
Global Const MQENC_FLOAT_MASK = &HF00
Global Const MQENC_RESERVED_MASK = &HFFFFF000

' Encodings for Binary Integers
Global Const MQENC_INTEGER_UNDEFINED = &H0
Global Const MQENC_INTEGER_NORMAL = &H1
Global Const MQENC_INTEGER_REVERSED = &H2

' Encodings for Packed-Decimal Integers
Global Const MQENC_DECIMAL_UNDEFINED = &H0
Global Const MQENC_DECIMAL_NORMAL = &H10
Global Const MQENC_DECIMAL_REVERSED = &H20

'Encodings for Floating-Point Numbers'
Global Const MQENC_FLOAT_UNDEFINED = &H0
Global Const MQENC_FLOAT_IEEE_NORMAL = &H100
Global Const MQENC_FLOAT_IEEE_REVERSED = &H200
Global Const MQENC_FLOAT_S390 = &H300

'Coded Character-Set Identifiers'
Global Const MQCCSI_DEFAULT = 0
Global Const MQCCSI_Q_MGR = 0
Global Const MQCCSI_INHERIT = -2
Global Const MQCCSI_EMBEDDED = -1

'Formats'
Global Const MQFMT_NONE = "        "
Global Const MQFMT_ADMIN = "MQADMIN "
Global Const MQFMT_CHANNEL_COMPLETED = "MQCHCOM "
Global Const MQFMT_CICS = "MQCICS  "
Global Const MQFMT_COMMAND_1 = "MQCMD1  "
Global Const MQFMT_COMMAND_2 = "MQCMD2  "
Global Const MQFMT_DEAD_LETTER_HEADER = "MQDEAD  "
Global Const MQFMT_DIST_HEADER = "MQHDIST "
Global Const MQFMT_EVENT = "MQEVENT "
Global Const MQFMT_IMS = "MQIMS   "
Global Const MQFMT_IMS_VAR_STRING = "MQIMSVS "
Global Const MQFMT_MD_EXTENSION = "MQHMDE  "
Global Const MQFMT_PCF = "MQPCF   "
Global Const MQFMT_REF_MSG_HEADER = "MQHREF  "
Global Const MQFMT_RF_HEADER = "MQHRF  "
Global Const MQFMT_STRING = "MQSTR   "
Global Const MQFMT_TRIGGER = "MQTRIG  "
Global Const MQFMT_WORK_INFO_HEADER = "MQHWIH  "
Global Const MQFMT_XMIT_Q_HEADER = "MQXMIT  "

' Priority
Global Const MQPRI_PRIORITY_AS_Q_DEF = -1

' Persistence Values
Global Const MQPER_PERSISTENT = 1
Global Const MQPER_NOT_PERSISTENT = 0
Global Const MQPER_PERSISTENCE_AS_Q_DEF = 2

' Message Id
Public MQMI_NONE As String * 24 'must initialise with MQSET_DEFAULTS call

' Correlation Id
Public MQCI_NONE As String * 24 'must initialise with MQSET_DEFAULTS call

' Accounting Token
Public MQACT_NONE As String * 32 'must initialise with MQSET_DEFAULTS call

' Accounting Token Type
Global Const MQACTT_UNKNOWN = &H0
Global Const MQACTT_CICS_LUOW_ID = &H1
Global Const MQACTT_MVS_JES_ACCOUNT_TOKEN = &H2
Global Const MQACTT_IMS_ACCOUNT_TOKEN = &H3
Global Const MQACTT_OS2_DEFAULT = &H4
Global Const MQACTT_DOS_DEFAULT = &H5
Global Const MQACTT_UNIX_NUMERIC_ID = &H6
Global Const MQACTT_OS400_ACCOUNT_TOKEN = &H8
Global Const MQACTT_WINDOWS_DEFAULT = &H9
Global Const MQACTT_NT_SECURITY_ID = &HB
Global Const MQACTT_MVS_TSO_ACCOUNT_TOKEN = &H18
Global Const MQACTT_USER = &H19

'Put Application Types'
Global Const MQAT_UNKNOWN = -1
Global Const MQAT_NO_CONTEXT = 0
Global Const MQAT_CICS = 1
Global Const MQAT_MVS = 2
Global Const MQAT_OS390 = 2
Global Const MQAT_IMS = 3
Global Const MQAT_OS2 = 4
Global Const MQAT_DOS = 5
Global Const MQAT_AIX = 6
Global Const MQAT_UNIX = 6
Global Const MQAT_QMGR = 7
Global Const MQAT_OS400 = 8
Global Const MQAT_WINDOWS = 9
Global Const MQAT_CICS_VSE = 10
Global Const MQAT_WINDOWS_NT = 11
Global Const MQAT_VMS = 12
Global Const MQAT_GUARDIAN = 13
Global Const MQAT_NSK = 13
Global Const MQAT_VOS = 14
Global Const MQAT_IMS_BRIDGE = 19
Global Const MQAT_XCF = 20
Global Const MQAI_CICS_BRIDGE = 21
Global Const MQAT_NOTES_AGENT = 22
Global Const MQAT_BROKER = 26
Global Const MQAT_DEFAULT = 11
Global Const MQAT_USER_FIRST = 65536
Global Const MQAT_USER_LAST = 999999999


'Group Identifier
Public MQGI_NONE As String * 24  'must initialise with MQSET_DEFAULTS call

'Message Flags
Global Const MQMF_SEGMENTATION_INHIBITED = &H0
Global Const MQMF_SEGMENTATION_ALLOWED = &H1
Global Const MQMF_MSG_IN_GROUP = &H8
Global Const MQMF_LAST_MSG_IN_GROUP = &H10
Global Const MQMF_SEGMENT = &H2
Global Const MQMF_LAST_SEGMENT = &H4
Global Const MQMF_NONE = &H0

'Message Flags Masks
Global Const MQMF_REJECT_UNSUP_MASK = &HFFF
Global Const MQMF_ACCEPT_UNSUP_MASK = &HFFF00000
Global Const MQMF_ACCEPT_UNSUP_IF_XMIT_MASK = &HFF000

'Original Length
Global Const MQOL_UNDEFINED = -1

'*********************************************************************'
'*  Values Related to MQMDE Structure                                *'
'*********************************************************************'

'Structure Identifier
Global Const MQMDE_STRUC_ID = "MDE "

'Structure Version Number
Global Const MQMDE_VERSION_2 = 2
Global Const MQMDE_CURRENT_VERSION = 2

'Structure Length
Global Const MQMDE_LENGTH_2 = 72

'General Flags
Global Const MQMDEF_NONE = 0

'**********************************************************************'
'*  Values Related to MQOD Structure                                  *'
'**********************************************************************'

' Structure Identifier
Global Const MQOD_STRUC_ID = "OD  "

' Structure Version Number
Global Const MQOD_VERSION_1 = 1
Global Const MQOD_VERSION_2 = 2
Global Const MQOD_VERSION_3 = 3
Global Const MQOD_CURRENT_VERSION = 3

' Structure Length
Global Const MQOD_CURRENT_LENGTH = 336

' Object Types
Global Const MQOT_Q = 1
Global Const MQOT_NAMELIST = 2
Global Const MQOT_PROCESS = 3
Global Const MQOT_Q_MGR = 5
Global Const MQOT_CHANNEL = 6
Global Const MQOT_RESERVED_1 = 7

' Extended Object Types
Global Const MQOT_ALL = 1001
Global Const MQOT_ALIAS_Q = 1002
Global Const MQOT_MODEL_Q = 1003
Global Const MQOT_LOCAL_Q = 1004
Global Const MQOT_REMOTE_Q = 1005
Global Const MQOT_SENDER_CHANNEL = 1007
Global Const MQOT_SERVER_CHANNEL = 1008
Global Const MQOT_REQUESTER_CHANNEL = 1009
Global Const MQOT_RECEIVER_CHANNEL = 1010
Global Const MQOT_CURRENT_CHANNEL = 1011
Global Const MQOT_SAVED_CHANNEL = 1012
Global Const MQOT_SVRCONN_CHANNEL = 1013
Global Const MQOT_CLNTCONN_CHANNEL = 1014
 
' Security Id
Public MQSID_NONE As String * 40

' Security Id Type
Global Const MQSIDT_NONE = 0
Global Const MQSIDT_NT_SECURITY_ID = 1

'**********************************************************************'
'*  Values Related to MQPMO Structure                                 *'
'**********************************************************************'

' Structure Identifier
Global Const MQPMO_STRUC_ID = "PMO "

' Structure Version Number
Global Const MQPMO_VERSION_1 = 1
Global Const MQPMO_VERSION_2 = 2
Global Const MQPMO_CURRENT_VERSION = 2

' Structure Length
Global Const MQPMO_CURRENT_LENGTH = 152

' Put-Message Options
Global Const MQPMO_SYNCPOINT = 2
Global Const MQPMO_NO_SYNCPOINT = 4
Global Const MQPMO_NEW_MSG_ID = 64
Global Const MQPMO_NEW_CORREL_ID = 128
Global Const MQPMO_LOGICAL_ORDER = 32768
Global Const MQPMO_NO_CONTEXT = 16384
Global Const MQPMO_DEFAULT_CONTEXT = 32
Global Const MQPMO_PASS_IDENTITY_CONTEXT = 256
Global Const MQPMO_PASS_ALL_CONTEXT = 512
Global Const MQPMO_SET_IDENTITY_CONTEXT = 1024
Global Const MQPMO_SET_ALL_CONTEXT = 2048
Global Const MQPMO_ALTERNATE_USER_AUTHORITY = 4096
Global Const MQPMO_FAIL_IF_QUIESCING = 8192
Global Const MQPMO_NONE = 0

' Put Message Record Fields
Global Const MQPMRF_MSG_ID = 1
Global Const MQPMRF_CORREL_ID = 2
Global Const MQPMRF_GROUP_ID = 4
Global Const MQPMRF_FEEDBACK = 8
Global Const MQPMRF_ACCOUNTING_TOKEN = 16
Global Const MQPMRF_NONE = 0

'*********************************************************************'
'*  Values Related to MQRFH Structure                                *'
'*********************************************************************'

' Structure Identifier
Global Const MQRFH_STRUC_ID = "RFH "

' Structure Version Number */
Global Const MQRFH_VERSION_1 = 1

' Structure Length */
Global Const MQRFH_STRUC_LENGTH_FIXED = 32

' Flags */
Global Const MQRFH_NONE =0

' Names for Name/Value String */
Global Const MQNVS_APPL_TYPE = "OPT_APP_GRP "
Global Const MQNVS_MSG_TYPE  = "OPT_MSG_TYPE "


'*********************************************************************'
'  Values Related to MQRMH Structure                                 *'
'*********************************************************************'

' Structure Identifier
Global Const MQRMH_STRUC_ID = "RMH "

'Structure Version Number
Global Const MQRMH_VERSION_1 = 1
Global Const MQRMH_CURRENT_VERSION = 1

'Flags
Global Const MQRMHF_LAST = 1
Global Const MQRMHF_NOT_LAST = 0

'Object Instance Identifier
Public MQOII_NONE As String * 24  'must initialise with MQSET_DEFAULTS call

'**********************************************************************'
'*  Values Related to MQTM Structure                                  *'
'**********************************************************************'

'Structure Identifier'
Global Const MQTM_STRUC_ID = "TM  "

'Structure Version Number'
Global Const MQTM_VERSION_1 = 1
Global Const MQTM_CURRENT_VERSION = 1


'**********************************************************************'
'*  Values Related to MQTMC2 Structure                                *'
'**********************************************************************'

'Structure Identifier'
Global Const MQTMC_STRUC_ID = "TMC "

'Structure Version Number'
Global Const MQTMC_VERSION_1 = "   1"
Global Const MQTMC_VERSION_2 = "   2"
Global Const MQTMC_CURRENT_VERSION = "   2"

'*********************************************************************'
'*  Values Related to MQWIH Structure                                *'
'*********************************************************************'

' Structure Identifier
Global Const MQWIH_STRUC_ID = "WIH "

' Structure Version Number
Global Const MQWIH_VERSION_1 = 1
Global Const MQWIH_CURRENT_VERSION = 1

' Structure Length
Global Const MQWIH_LENGTH_1 = 120
Global Const MQWIH_CURRENT_LENGTH = 120

' Flags
Global Const MQWIH_NONE = 0

'**********************************************************************'
'*  Values Related to MQXQH Structure                                 *'
'**********************************************************************'

'Structure Identifier'
Global Const MQXQH_STRUC_ID = "XQH "

'Structure Version Number'
Global Const MQXQH_VERSION_1 = 1
Global Const MQXQH_CURRENT_VERSION = 1


'**********************************************************************'
'*  Values Related to MQNL Structure                                  *'
'**********************************************************************'
' Structure Identifier
Global Const MQNL_STRUC_ID = "NL "

' Structure Version Number
Global Const MQNL_VERSION_1 = 1
Global Const MQNL_CURRENT_VERSION = 1


'**********************************************************************'
'*  Values Related to MQCLOSE Call                                    *'
'**********************************************************************'

' Object Handle
Global Const MQHO_UNUSABLE_HOBJ = -1

' Close Options
Global Const MQCO_NONE = 0
Global Const MQCO_DELETE = 1
Global Const MQCO_DELETE_PURGE = 2


'**********************************************************************'
'*  Values Related to MQINQ Call                                      *'
'**********************************************************************'

' Character-Attribute Selectors
Global Const MQCA_ALTERATION_DATE = 2027
Global Const MQCA_ALTERATION_TIME = 2028
Global Const MQCA_APPL_ID = 2001
Global Const MQCA_BACKOUT_REQ_Q_NAME = 2019
Global Const MQCA_BASE_Q_NAME = 2002
Global Const MQCA_CHANNEL_AUTO_DEF_EXIT = 2026
Global Const MQCA_CLUSTER_DATE = 2037
Global Const MQCA_CLUSTER_Q_MGR_IDENTIFIER = 2032
Global Const MQCA_CLUSTER_NAME = 2029
Global Const MQCA_CLUSTER_NAMELIST = 2030
Global Const MQCA_CLUSTER_Q_MGR_NAME = 2031
Global Const MQCA_CLUSTER_TIME = 2038
Global Const MQCA_CLUSTER_WORKLOAD_DATA = 2034
Global Const MQCA_CLUSTER_WORKLOAD_EXIT = 2033
Global Const MQCA_COMMAND_INPUT_Q_NAME = 2003
Global Const MQCA_CREATION_DATE = 2004
Global Const MQCA_CREATION_TIME = 2005
Global Const MQCA_DEAD_LETTER_Q_NAME = 2006
Global Const MQCA_DEF_XMIT_Q_NAME = 2025
Global Const MQCA_ENV_DATA = 2007
Global Const MQCA_FIRST = 2001
Global Const MQCA_INITIATION_Q_NAME = 2008
Global Const MQCA_LAST = 4000
Global Const MQCA_LAST_USED = 2038
Global Const MQCA_NAMELIST_DESC = 2009
Global Const MQCA_NAMELIST_NAME = 2010
Global Const MQCA_NAMES = 2020
Global Const MQCA_PROCESS_DESC = 2011
Global Const MQCA_PROCESS_NAME = 2012
Global Const MQCA_Q_DESC = 2013
Global Const MQCA_Q_MGR_DESC = 2014
Global Const MQCA_Q_MGR_IDENTIFIER = 2032
Global Const MQCA_Q_MGR_NAME = 2015
Global Const MQCA_Q_NAME = 2016
Global Const MQCA_REMOTE_Q_MGR_NAME = 2017
Global Const MQCA_REMOTE_Q_NAME = 2018
Global Const MQCA_REPOSITORY_NAME = 2035
Global Const MQCA_REPOSITORY_NAMELIST = 2036
Global Const MQCA_STORAGE_CLASS = 2022
Global Const MQCA_TRIGGER_DATA = 2023
Global Const MQCA_USER_DATA = 2021
Global Const MQCA_USER_LIST = 4000
Global Const MQCA_WORK_LOAD_MANAGER_EXIT = 2027
Global Const MQCA_WORK_LOAD_MANAGER_DATA = 2028
Global Const MQCA_XMIT_Q_NAME = 2024

'Integer-Attribute Selectors'
Global Const MQIA_APPL_TYPE = 1
Global Const MQIA_ARCHIVE = 60
Global Const MQIA_AUTHORITY_EVENT = 47
Global Const MQIA_BACKOUT_THRESHOLD = 22
Global Const MQIA_CHANNEL_AUTO_DEF = 55
Global Const MQIA_CHANNEL_AUTO_DEF_EVENT = 56
Global Const MQIA_CLUSTER_Q_TYPE = 59
Global Const MQIA_CLUSTER_WORKLOAD_LENGTH = 58
Global Const MQIA_CLWLLEN = 62
Global Const MQIA_CODED_CHAR_SET_ID = 2
Global Const MQIA_COMMAND_LEVEL = 31
Global Const MQIA_CURRENT_Q_DEPTH = 3
Global Const MQIA_DEF_BIND = 61
Global Const MQIA_DEF_INPUT_OPEN_OPTION = 4
Global Const MQIA_DEF_PERSISTENCE = 5
Global Const MQIA_DEF_PRIORITY = 6
Global Const MQIA_DEFINITION_TYPE = 7
Global Const MQIA_DIST_LISTS = 34
Global Const MQIA_FIRST = 1
Global Const MQIA_HARDEN_GET_BACKOUT = 8
Global Const MQIA_HIGH_Q_DEPTH = 36
Global Const MQIA_INDEX_TYPE = 57
Global Const MQIA_INHIBIT_EVENT = 48
Global Const MQIA_INHIBIT_GET = 9
Global Const MQIA_INHIBIT_PUT = 10
Global Const MQIA_LAST = 2000
Global Const MQIA_LAST_USED = 61
Global Const MQIA_LOCAL_EVENT = 49
Global Const MQIA_MAX_HANDLES = 11
Global Const MQIA_MAX_MSG_LENGTH = 13
Global Const MQIA_MAX_PRIORITY = 14
Global Const MQIA_MAX_Q_DEPTH = 15
Global Const MQIA_MAX_UNCOMMITTED_MSGS = 33
Global Const MQIA_MSG_DELIVERY_SEQUENCE = 16
Global Const MQIA_MSG_DEQ_COUNT = 38
Global Const MQIA_MSG_ENQ_COUNT = 37
Global Const MQIA_NAME_COUNT = 19
Global Const MQIA_OPEN_INPUT_COUNT = 17
Global Const MQIA_OPEN_OUTPUT_COUNT = 18
Global Const MQIA_PERFORMANCE_EVENT = 53
Global Const MQIA_PLATFORM = 32
Global Const MQIA_Q_DEPTH_HIGH_EVENT = 43
Global Const MQIA_Q_DEPTH_HIGH_LIMIT = 40
Global Const MQIA_Q_DEPTH_LOW_EVENT = 44
Global Const MQIA_Q_DEPTH_LOW_LIMIT = 41
Global Const MQIA_Q_DEPTH_MAX_EVENT = 42
Global Const MQIA_Q_SERVICE_INTERVAL = 54
Global Const MQIA_Q_SERVICE_INTERVAL_EVENT = 46
Global Const MQIA_Q_TYPE = 20
Global Const MQIA_REMOTE_EVENT = 50
Global Const MQIA_RETENTION_INTERVAL = 21
Global Const MQIA_SCOPE = 45
Global Const MQIA_SHAREABILITY = 23
Global Const MQIA_START_STOP_EVENT = 52
Global Const MQIA_SYNCPOINT = 30
Global Const MQIA_TIME_SINCE_RESET = 35
Global Const MQIA_TRIGGER_CONTROL = 24
Global Const MQIA_TRIGGER_DEPTH = 29
Global Const MQIA_TRIGGER_INTERVAL = 25
Global Const MQIA_TRIGGER_MSG_PRIORITY = 26
Global Const MQIA_TRIGGER_TYPE = 28
Global Const MQIA_USAGE = 12
Global Const MQIA_USER_LIST = 2000
Global Const MQIA_WORK_LOAD_MANAGER = 60

' Integer Attribute Value Denoting "Not Applicable"
Global Const MQIAV_NOT_APPLICABLE = -1
Global Const MQIAV_UNDEFINED = -2

'**********************************************************************'
'*  Values Related to MQOPEN Call                                     *'
'**********************************************************************'

' Open Options
Global Const MQOO_INPUT_AS_Q_DEF = 1
Global Const MQOO_INPUT_SHARED = 2
Global Const MQOO_INPUT_EXCLUSIVE = 4
Global Const MQOO_BROWSE = 8
Global Const MQOO_OUTPUT = 16
Global Const MQOO_INQUIRE = 32
Global Const MQOO_SET = 64
Global Const MQOO_SAVE_ALL_CONTEXT = 128
Global Const MQOO_PASS_IDENTITY_CONTEXT = 256
Global Const MQOO_PASS_ALL_CONTEXT = 512
Global Const MQOO_SET_IDENTITY_CONTEXT = 1024
Global Const MQOO_SET_ALL_CONTEXT = 2048
Global Const MQOO_ALTERNATE_USER_AUTHORITY = 4096
Global Const MQOO_FAIL_IF_QUIESCING = 8192
Global Const MQOO_BIND_AS_Q_DEF = &H0
Global Const MQOO_BIND_ON_OPEN = &H4000
Global Const MQOO_BIND_NOT_FIXED = &H8000
Global Const MQOO_RESOLVE_NAMES = &H10000

'**********************************************************************'
'*  Values Related to All Calls                                       *'
'**********************************************************************'

' Connection Handle
Global Const MQHC_DEF_HCONN = 0
Global Const MQHC_UNUSABLE_HCONN = -1

' String Lengths
Global Const MQ_ABEND_CODE_LENGTH = 4
Global Const MQ_ACCOUNTING_TOKEN_LENGTH = 32
Global Const MQ_ALTERATION_DATE_LENGTH = 12
Global Const MQ_ALTERATION_TIME_LENGTH = 8
Global Const MQ_APPL_IDENTITY_DATA_LENGTH = 32
Global Const MQ_APPL_NAME_LENGTH = 28
Global Const MQ_APPL_ORIGIN_DATA_LENGTH = 4
Global Const MQ_ATTENTION_ID_LENGTH = 4
Global Const MQ_AUTHENTICATOR_LENGTH = 8
Global Const MQ_BRIDGE_NAME_LENGTH = 24
Global Const MQ_CANCEL_CODE_LENGTH = 4
Global Const MQ_CHANNEL_DATE_LENGTH = 12
Global Const MQ_CHANNEL_DESC_LENGTH = 64
Global Const MQ_CHANNEL_NAME_LENGTH = 20
Global Const MQ_CHANNEL_TIME_LENGTH = 8
Global Const MQ_CONN_NAME_LENGTH = 264
Global Const MQ_CORREL_ID_LENGTH = 24
Global Const MQ_CREATION_DATE_LENGTH = 12
Global Const MQ_CREATION_TIME_LENGTH = 8
Global Const MQ_DATE_LENGTH = 12
Global Const MQ_EXIT_DATA_LENGTH = 32
Global Const MQ_EXIT_NAME_LENGTH = 128
Global Const MQ_EXIT_USER_AREA_LENGTH = 16
Global Const MQ_FACILITY_LENGTH = 8
Global Const MQ_FACILITY_LIKE_LENGTH = 4
Global Const MQ_FORMAT_LENGTH = 8
Global Const MQ_FUNCTION_LENGTH = 4
Global Const MQ_GROUP_ID_LENGTH = 24
Global Const MQ_LTERM_OVERRIDE_LENGTH = 8
Global Const MQ_LUWID_LENGTH = 16
Global Const MQ_MAX_EXIT_NAME_LENGTH = 128
Global Const MQ_MAX_MCA_USER_ID_LENGTH = 64
Global Const MQ_MCA_JOB_NAME_LENGTH = 28
Global Const MQ_MCA_NAME_LENGTH = 20
' MQ_MCA_USER_ID_LENGTH = 12 for Win31
Global Const MQ_MCA_USER_ID_LENGTH = 64
Global Const MQ_MFS_MAP_NAME_LENGTH = 8
Global Const MQ_MODE_NAME_LENGTH = 8
Global Const MQ_MSG_HEADER_LENGTH = 4000
Global Const MQ_MSG_ID_LENGTH = 24
Global Const MQ_MSG_TOKEN_LENGTH = 16
Global Const MQ_NAMELIST_DESC_LENGTH = 64
Global Const MQ_NAMELIST_NAME_LENGTH = 48
Global Const MQNC_MAX_NAMELIST_NAME_COUNT = 256
Global Const MQ_NL_NAMES_LENGTH = 12288
Global Const MQ_OBJECT_INSTANCE_ID_LENGTH = 24
Global Const MQ_OBJECT_NAME_LENGTH = 48
Global Const MQ_PASSWORD_LENGTH = 12
Global Const MQ_PROCESS_APPL_ID_LENGTH = 256
Global Const MQ_PROCESS_DESC_LENGTH = 64
Global Const MQ_PROCESS_ENV_DATA_LENGTH = 128
Global Const MQ_PROCESS_NAME_LENGTH = 48
Global Const MQ_PROCESS_USER_DATA_LENGTH = 128
Global Const MQ_PUT_APPL_NAME_LENGTH = 28
Global Const MQ_PUT_DATE_LENGTH = 8
Global Const MQ_PUT_TIME_LENGTH = 8
Global Const MQ_Q_DESC_LENGTH = 64
Global Const MQ_Q_MGR_DESC_LENGTH = 64
Global Const MQ_Q_MGR_IDENTIFIER_LENGTH = 48
Global Const MQ_Q_MGR_NAME_LENGTH = 48
Global Const MQ_Q_NAME_LENGTH = 48
Global Const MQ_REMOTE_SYS_ID_LENGTH = 4
Global Const MQ_SECURITY_ID_LENGTH = 40
Global Const MQ_SERVICE_NAME_LENGTH = 32
Global Const MQ_SERVICE_STEP_LENGTH = 8
Global Const MQ_SHORT_CONN_NAME_LENGTH = 20
Global Const MQ_START_CODE_LENGTH = 4
Global Const MQ_STORAGE_CLASS_LENGTH = 8
Global Const MQ_TIME_LENGTH = 8
Global Const MQ_TOTAL_EXIT_DATA_LENGTH = 999
Global Const MQ_TOTAL_EXIT_NAME_LENGTH = 999
Global Const MQ_TP_NAME_LENGTH = 64
Global Const MQ_TRAN_INSTANCE_ID_LENGTH = 16
Global Const MQ_TRANSACTION_ID_LENGTH = 4
Global Const MQ_TRIGGER_DATA_LENGTH = 64
Global Const MQ_USER_ID_LENGTH = 12
Global Const MQ_CLUSTER_NAME_LENGTH = 48

'Completion Codes'
Global Const MQCC_OK = 0
Global Const MQCC_WARNING = 1
Global Const MQCC_FAILED = 2
Global Const MQCC_UNKNOWN = -1

'Reason Codes'
Global Const MQRC_NONE = 0
Global Const MQRC_ALIAS_BASE_Q_TYPE_ERROR = 2001
Global Const MQRC_ALREADY_CONNECTED = 2002
Global Const MQRC_BACKED_OUT = 2003
Global Const MQRC_BUFFER_ERROR = 2004
Global Const MQRC_BUFFER_LENGTH_ERROR = 2005
Global Const MQRC_CHAR_ATTR_LENGTH_ERROR = 2006
Global Const MQRC_CHAR_ATTRS_ERROR = 2007
Global Const MQRC_CHAR_ATTRS_TOO_SHORT = 2008
Global Const MQRC_CONNECTION_BROKEN = 2009
Global Const MQRC_DATA_LENGTH_ERROR = 2010
Global Const MQRC_DYNAMIC_Q_NAME_ERROR = 2011
Global Const MQRC_ENVIRONMENT_ERROR = 2012
Global Const MQRC_EXPIRY_ERROR = 2013
Global Const MQRC_FEEDBACK_ERROR = 2014
Global Const MQRC_GET_INHIBITED = 2016
Global Const MQRC_HANDLE_NOT_AVAILABLE = 2017
Global Const MQRC_HCONN_ERROR = 2018
Global Const MQRC_HOBJ_ERROR = 2019
Global Const MQRC_INHIBIT_VALUE_ERROR = 2020
Global Const MQRC_INT_ATTR_COUNT_ERROR = 2021
Global Const MQRC_INT_ATTR_COUNT_TOO_SMALL = 2022
Global Const MQRC_INT_ATTRS_ARRAY_ERROR = 2023
Global Const MQRC_SYNCPOINT_LIMIT_REACHED = 2024
Global Const MQRC_MAX_CONNS_LIMIT_REACHED = 2025
Global Const MQRC_MD_ERROR = 2026
Global Const MQRC_MISSING_REPLY_TO_Q = 2027
Global Const MQRC_MSG_TYPE_ERROR = 2029
Global Const MQRC_MSG_TOO_BIG_FOR_Q = 2030
Global Const MQRC_MSG_TOO_BIG_FOR_Q_MGR = 2031
Global Const MQRC_NO_MSG_AVAILABLE = 2033
Global Const MQRC_NO_MSG_UNDER_CURSOR = 2034
Global Const MQRC_NOT_AUTHORIZED = 2035
Global Const MQRC_NOT_OPEN_FOR_BROWSE = 2036
Global Const MQRC_NOT_OPEN_FOR_INPUT = 2037
Global Const MQRC_NOT_OPEN_FOR_INQUIRE = 2038
Global Const MQRC_NOT_OPEN_FOR_OUTPUT = 2039
Global Const MQRC_NOT_OPEN_FOR_SET = 2040
Global Const MQRC_OBJECT_CHANGED = 2041
Global Const MQRC_OBJECT_IN_USE = 2042
Global Const MQRC_OBJECT_TYPE_ERROR = 2043
Global Const MQRC_OD_ERROR = 2044
Global Const MQRC_OPTION_NOT_VALID_FOR_TYPE = 2045
Global Const MQRC_OPTIONS_ERROR = 2046
Global Const MQRC_PERSISTENCE_ERROR = 2047
Global Const MQRC_PERSISTENT_NOT_ALLOWED = 2048
Global Const MQRC_PRIORITY_EXCEEDS_MAXIMUM = 2049
Global Const MQRC_PRIORITY_ERROR = 2050
Global Const MQRC_PUT_INHIBITED = 2051
Global Const MQRC_Q_DELETED = 2052
Global Const MQRC_Q_FULL = 2053
Global Const MQRC_Q_NOT_EMPTY = 2055
Global Const MQRC_Q_SPACE_NOT_AVAILABLE = 2056
Global Const MQRC_Q_TYPE_ERROR = 2057
Global Const MQRC_Q_MGR_NAME_ERROR = 2058
Global Const MQRC_Q_MGR_NOT_AVAILABLE = 2059
Global Const MQRC_REPORT_OPTIONS_ERROR = 2061
Global Const MQRC_SECOND_MARK_NOT_ALLOWED = 2062
Global Const MQRC_SECURITY_ERROR = 2063
Global Const MQRC_SELECTOR_COUNT_ERROR = 2065
Global Const MQRC_SELECTOR_LIMIT_EXCEEDED = 2066
Global Const MQRC_SELECTOR_ERROR = 2067
Global Const MQRC_SELECTOR_NOT_FOR_TYPE = 2068
Global Const MQRC_SIGNAL_OUTSTANDING = 2069
Global Const MQRC_SIGNAL_REQUEST_ACCEPTED = 2070
Global Const MQRC_STORAGE_NOT_AVAILABLE = 2071
Global Const MQRC_SYNCPOINT_NOT_AVAILABLE = 2072
Global Const MQRC_TRIGGER_CONTROL_ERROR = 2075
Global Const MQRC_TRIGGER_DEPTH_ERROR = 2076
Global Const MQRC_TRIGGER_MSG_PRIORITY_ERR = 2077
Global Const MQRC_TRIGGER_TYPE_ERROR = 2078
Global Const MQRC_TRUNCATED_MSG_ACCEPTED = 2079
Global Const MQRC_TRUNCATED_MSG_FAILED = 2080
Global Const MQRC_UNKNOWN_ALIAS_BASE_Q = 2082
Global Const MQRC_UNKNOWN_OBJECT_NAME = 2085
Global Const MQRC_UNKNOWN_OBJECT_Q_MGR = 2086
Global Const MQRC_UNKNOWN_REMOTE_Q_MGR = 2087
Global Const MQRC_WAIT_INTERVAL_ERROR = 2090
Global Const MQRC_XMIT_Q_TYPE_ERROR = 2091
Global Const MQRC_XMIT_Q_USAGE_ERROR = 2092
Global Const MQRC_NOT_OPEN_FOR_PASS_ALL = 2093
Global Const MQRC_NOT_OPEN_FOR_PASS_IDENT = 2094
Global Const MQRC_NOT_OPEN_FOR_SET_ALL = 2095
Global Const MQRC_NOT_OPEN_FOR_SET_IDENT = 2096
Global Const MQRC_CONTEXT_HANDLE_ERROR = 2097
Global Const MQRC_CONTEXT_NOT_AVAILABLE = 2098
Global Const MQRC_SIGNAL1_ERROR = 2099
Global Const MQRC_OBJECT_ALREADY_EXISTS = 2100
Global Const MQRC_OBJECT_DAMAGED = 2101
Global Const MQRC_RESOURCE_PROBLEM = 2102
Global Const MQRC_ANOTHER_Q_MGR_CONNECTED = 2103
Global Const MQRC_UNKNOWN_REPORT_OPTION = 2104
Global Const MQRC_STORAGE_CLASS_ERROR = 2105
Global Const MQRC_COD_NOT_VALID_FOR_XCF_Q = 2106
Global Const MQRC_XWAIT_CANCELED = 2107
Global Const MQRC_XWAIT_ERROR = 2108
Global Const MQRC_SUPPRESSED_BY_EXIT = 2109
Global Const MQRC_FORMAT_ERROR = 2110
Global Const MQRC_SOURCE_CCSID_ERROR = 2111
Global Const MQRC_SOURCE_INTEGER_ENC_ERROR = 2112
Global Const MQRC_SOURCE_DECIMAL_ENC_ERROR = 2113
Global Const MQRC_SOURCE_FLOAT_ENC_ERROR = 2114
Global Const MQRC_TARGET_CCSID_ERROR = 2115
Global Const MQRC_TARGET_INTEGER_ENC_ERROR = 2116
Global Const MQRC_TARGET_DECIMAL_ENC_ERROR = 2117
Global Const MQRC_TARGET_FLOAT_ENC_ERROR = 2118
Global Const MQRC_NOT_CONVERTED = 2119
Global Const MQRC_CONVERTED_MSG_TOO_BIG = 2120
Global Const MQRC_TRUNCATED = 2120
Global Const MQRC_NO_EXTERNAL_PARTICIPANTS = 2121
Global Const MQRC_PARTICIPANT_NOT_AVAILABLE = 2122
Global Const MQRC_OUTCOME_MIXED = 2123
Global Const MQRC_OUTCOME_PENDING = 2124
Global Const MQRC_BRIDGE_STARTED = 2125
Global Const MQRC_BRIDGE_STOPPED = 2126
Global Const MQRC_ADAPTER_STORAGE_SHORTAGE = 2127
Global Const MQRC_UOW_IN_PROGRESS = 2128
Global Const MQRC_ADAPTER_CONN_LOAD_ERROR = 2129
Global Const MQRC_ADAPTER_SERV_LOAD_ERROR = 2130
Global Const MQRC_ADAPTER_DEFS_ERROR = 2131
Global Const MQRC_ADAPTER_DEFS_LOAD_ERROR = 2132
Global Const MQRC_ADAPTER_CONV_LOAD_ERROR = 2133
Global Const MQRC_BO_ERROR = 2134
Global Const MQRC_DH_ERROR = 2135
Global Const MQRC_MULTIPLE_REASONS = 2136
Global Const MQRC_OPEN_FAILED = 2137
Global Const MQRC_ADAPTER_DISC_LOAD_ERROR = 2138
Global Const MQRC_CNO_ERROR = 2139
Global Const MQRC_CICS_WAIT_FAILED = 2140
Global Const MQRC_DLH_ERROR = 2141
Global Const MQRC_HEADER_ERROR = 2142
Global Const MQRC_SOURCE_LENGTH_ERROR = 2143
Global Const MQRC_TARGET_LENGTH_ERROR = 2144
Global Const MQRC_SOURCE_BUFFER_ERROR = 2145
Global Const MQRC_TARGET_BUFFER_ERROR = 2146
Global Const MQRC_IIH_ERROR = 2148
Global Const MQRC_PCF_ERROR = 2149
Global Const MQRC_DBCS_ERROR = 2150
Global Const MQRC_OBJECT_NAME_ERROR = 2152
Global Const MQRC_OBJECT_Q_MGR_NAME_ERROR = 2153
Global Const MQRC_RECS_PRESENT_ERROR = 2154
Global Const MQRC_OBJECT_RECORDS_ERROR = 2155
Global Const MQRC_RESPONSE_RECORDS_ERROR = 2156
Global Const MQRC_ASID_MISMATCH = 2157
Global Const MQRC_PMO_RECORD_FLAGS_ERROR = 2158
Global Const MQRC_PUT_MSG_RECORDS_ERROR = 2159
Global Const MQRC_CONN_ID_IN_USE = 2160
Global Const MQRC_Q_MGR_QUIESCING = 2161
Global Const MQRC_Q_MGR_STOPPING = 2162
Global Const MQRC_DUPLICATE_RECOV_COORD = 2163
Global Const MQRC_PMO_ERROR = 2173
Global Const MQRC_API_EXIT_NOT_FOUND = 2182
Global Const MQRC_API_EXIT_LOAD_ERROR = 2183
Global Const MQRC_REMOTE_Q_NAME_ERROR = 2184
Global Const MQRC_INCONSISTENT_PERSISTENCE = 2185
Global Const MQRC_GMO_ERROR = 2186
Global Const MQRC_CICS_BRIDGE_RESTRICTION = 2187
Global Const MQRC_STOPPED_BY_CLUSTER_EXIT = 2188
Global Const MQRC_CLUSTER_RESOLUTION_ERROR = 2189
Global Const MQRC_CONVERTED_STRING_TOO_BIG = 2190
Global Const MQRC_TMC_ERROR = 2191
Global Const MQRC_PAGESET_FULL = 2192
Global Const MQRC_PAGESET_ERROR = 2193
Global Const MQRC_NAME_NOT_VALID_FOR_TYPE = 2194
Global Const MQRC_UNEXPECTED_ERROR = 2195
Global Const MQRC_UNKNOWN_XMIT_Q = 2196
Global Const MQRC_UNKNOWN_DEF_XMIT_Q = 2197
Global Const MQRC_DEF_XMIT_Q_TYPE_ERROR = 2198
Global Const MQRC_DEF_XMIT_Q_USAGE_ERROR = 2199
Global Const MQRC_NAME_IN_USE = 2201
Global Const MQRC_CONNECTION_QUIESCING = 2202
Global Const MQRC_CONNECTION_STOPPING = 2203
Global Const MQRC_ADAPTER_NOT_AVAILABLE = 2204
Global Const MQRC_MSG_ID_ERROR = 2206
Global Const MQRC_CORREL_ID_ERROR = 2207
Global Const MQRC_FILE_SYSTEM_ERROR = 2208
Global Const MQRC_NO_MSG_LOCKED = 2209
Global Const MQRC_FILE_NOT_AUDITED = 2216
Global Const MQRC_CONNECTION_NOT_AUTHORIZED = 2217
Global Const MQRC_MSG_TOO_BIG_FOR_CHANNEL = 2218
Global Const MQRC_CALL_IN_PROGRESS = 2219
Global Const MQRC_RMH_ERROR = 2220
Global Const MQRC_Q_MGR_ACTIVE = 2222
Global Const MQRC_Q_MGR_NOT_ACTIVE = 2223
Global Const MQRC_Q_DEPTH_HIGH = 2224
Global Const MQRC_Q_DEPTH_LOW = 2225
Global Const MQRC_Q_SERVICE_INTERVAL_HIGH = 2226
Global Const MQRC_Q_SERVICE_INTERVAL_OK = 2227
Global Const MQRC_UNIT_OF_WORK_NOT_STARTED = 2232
Global Const MQRC_CHANNEL_AUTO_DEF_OK = 2233
Global Const MQRC_CHANNEL_AUTO_DEF_ERROR = 2234
Global Const MQRC_CFH_ERROR = 2235
Global Const MQRC_CFIL_ERROR = 2236
Global Const MQRC_CFIN_ERROR = 2237
Global Const MQRC_CFSL_ERROR = 2238
Global Const MQRC_CFST_ERROR = 2239
Global Const MQRC_INCOMPLETE_GROUP = 2241
Global Const MQRC_INCOMPLETE_MESSAGE = 2242
Global Const MQRC_INCONSISTENT_CCSIDS = 2243
Global Const MQRC_INCONSISTENT_ENCODING = 2244
Global Const MQRC_INCONSISTENT_UOW = 2245
Global Const MQRC_INVALID_MSG_UNDER_CURSOR = 2246
Global Const MQRC_MATCH_OPTIONS_ERROR = 2247
Global Const MQRC_MDE_ERROR = 2248
Global Const MQRC_MSG_FLAGS_ERROR = 2249
Global Const MQRC_MSG_SEQ_NUMBER_ERROR = 2250
Global Const MQRC_OFFSET_ERROR = 2251
Global Const MQRC_ORIGINAL_LENGTH_ERROR = 2252
Global Const MQRC_SEGMENT_LENGTH_ZERO = 2253
Global Const MQRC_UOW_NOT_AVAILABLE = 2255
Global Const MQRC_WRONG_GMO_VERSION = 2256
Global Const MQRC_WRONG_MD_VERSION = 2257
Global Const MQRC_GROUP_ID_ERROR = 2258
Global Const MQRC_INCONSISTENT_BROWSE = 2259
Global Const MQRC_XQH_ERROR = 2260
Global Const MQRC_SRC_ENV_ERROR = 2261
Global Const MQRC_SRC_NAME_ERROR = 2262
Global Const MQRC_DEST_ENV_ERROR = 2263
Global Const MQRC_DEST_NAME_ERROR = 2264
Global Const MQRC_TM_ERROR = 2265
Global Const MQRC_CLUSTER_EXIT_ERROR = 2266
Global Const MQRC_CLUSTER_EXIT_LOAD_ERROR = 2267
Global Const MQRC_CLUSTER_PUT_INBHIBITED = 2268
Global Const MQRC_CLUSTER_RESOURCE_ERROR = 2269
Global Const MQRC_NO_DESTINATIONS = 2270
Global Const MQRC_CONNECTION_ERROR = 2273
Global Const MQRC_OPTION_ENVIRONMENT_ERROR = 2274
Global Const MQRC_CD_ERROR = 2277
Global Const MQRC_CLIENT_CONN_ERROR = 2278
Global Const MQRC_CHANNEL_STOPPED_BY_USER = 2279
Global Const MQRC_HCONFIG_ERROR = 2280
Global Const MQRC_FUNCTION_ERROR = 2281
Global Const MQRC_CHANNEL_STARTED = 2282
Global Const MQRC_CHANNEL_STOPPED = 2283
Global Const MQRC_CHANNEL_CONV_ERROR = 2284
Global Const MQRC_SERVICE_NOT_AVAILABLE = 2285
Global Const MQRC_INITIALIZATION_FAILED = 2286
Global Const MQRC_TERMINATION_FAILED = 2287
Global Const MQRC_UNKNOWN_Q_NAME = 2288
Global Const MQRC_SERVICE_ERROR = 2289
Global Const MQRC_Q_ALREADY_EXISTS = 2290
Global Const MQRC_USER_ID_NOT_AVAILABLE = 2291
Global Const MQRC_UNKNOWN_ENTITY = 2292
Global Const MQRC_UNKNOWN_AUTH_ENTITY = 2293
Global Const MQRC_UNKNOWN_REF_OBJECT = 2294
Global Const MQRC_CHANNEL_ACTIVATED = 2295
Global Const MQRC_CHANNEL_NOT_ACTIVATED = 2296
Global Const MQRC_UOW_CANCELED = 2297
Global Const MQRC_SELECTOR_TYPE_ERROR = 2299
Global Const MQRC_COMMAND_TYPE_ERROR = 2300
Global Const MQRC_MULTIPLE_INSTANCE_ERROR = 2301
Global Const MQRC_SYSTEM_ITEM_NOT_ALTERABLE = 2302
Global Const MQRC_BAG_CONVERSION_ERROR = 2303
Global Const MQRC_SELECTOR_OUT_OF_RANGE = 2304
Global Const MQRC_SELECTOR_NOT_UNIQUE = 2305
Global Const MQRC_INDEX_NOT_PRESENT = 2306
Global Const MQRC_STRING_ERROR = 2307
Global Const MQRC_ENCODING_NOT_SUPPORTED = 2308
Global Const MQRC_SELECTOR_NOT_PRESENT = 2309
Global Const MQRC_OUT_SELECTOR_ERROR = 2310
Global Const MQRC_STRING_TRUNCATED = 2311
Global Const MQRC_SELECTOR_WRONG_TYPE = 2312
Global Const MQRC_INCONSISTENT_ITEM_TYPE = 2313
Global Const MQRC_INDEX_ERROR = 2314
Global Const MQRC_SYSTEM_BAG_NOT_ALTERABLE = 2315
Global Const MQRC_ITEM_COUNT_ERROR = 2316
Global Const MQRC_FORMAT_NOT_SUPPORTED = 2317
Global Const MQRC_SELECTOR_NOT_SUPPORTED = 2318
Global Const MQRC_ITEM_VALUE_ERROR = 2319
Global Const MQRC_HBAG_ERROR = 2320
Global Const MQRC_PARAMETER_MISSING = 2321
Global Const MQRC_CMD_SERVER_NOT_AVAILABLE = 2322
Global Const MQRC_STRING_LENGTH_ERROR = 2323
Global Const MQRC_INQUIRY_COMMAND_ERROR = 2324
Global Const MQRC_NESTED_BAG_NOT_SUPPORTED = 2325
Global Const MQRC_BAG_WRONG_TYPE = 2326
Global Const MQRC_ITEM_TYPE_ERROR = 2327
Global Const MQRC_SYSTEM_BAG_NOT_DELETABLE = 2328
Global Const MQRC_SYSTEM_ITEM_NOT_DELETABLE = 2329
Global Const MQRC_CODED_CHAR_SET_ID_ERROR = 2330
Global Const MQRC_CLUSTER_SET_ERROR = 2301
Global Const MQRC_USAGE_CLUSTER_SET_ERROR = 2302
Global Const MQRC_MSG_TOKEN_ERROR = 2331
Global Const MQRC_MISSING_WIH = 2332
Global Const MQRC_WIH_ERROR = 2333
Global Const MQRC_RFH_ERROR = 2334
Global Const MQRC_RFH_STRING_ERROR = 2335
Global Const MQRC_RFH_COMMAND_ERROR = 2336
Global Const MQRC_RFH_PARM_ERROR = 2337
Global Const MQRC_RFH_DUPLICATE_PARM = 2338
Global Const MQRC_RFH_PARM_MISSING = 2339
Global Const MQRC_APPL_FIRST = 900
Global Const MQRC_APPL_LAST = 999


'**********************************************************************'
'*  Values Related to Queue Attributes                                *'
'**********************************************************************'

' Queue Types
Global Const MQQT_LOCAL = 1
Global Const MQQT_MODEL = 2
Global Const MQQT_ALIAS = 3
Global Const MQQT_REMOTE = 6
Global Const MQQT_CLUSTER = 7

'* Cluster Queue Types *'
Global Const MQCQT_LOCAL_Q = 1
Global Const MQCQT_ALIAS_Q = 2
Global Const MQCQT_REMOTE_Q = 3
Global Const MQCQT_Q_MGR_ALIAS = 4


' Extended Queue Types
Global Const MQQT_ALL = 1001

' Queue Definition Types
Global Const MQQDT_PREDEFINED = 1
Global Const MQQDT_PERMANENT_DYNAMIC = 2
Global Const MQQDT_TEMPORARY_DYNAMIC = 3

' Inhibit Get
Global Const MQQA_GET_INHIBITED = 1
Global Const MQQA_GET_ALLOWED = 0

' Inhibit Put
Global Const MQQA_PUT_INHIBITED = 1
Global Const MQQA_PUT_ALLOWED = 0

' Queue Shareability
Global Const MQQA_SHAREABLE = 1
Global Const MQQA_NOT_SHAREABLE = 0

' Back-Out Hardening
Global Const MQQA_BACKOUT_HARDENED = 1
Global Const MQQA_BACKOUT_NOT_HARDENED = 0

' Message Delivery Sequence
Global Const MQMDS_PRIORITY = 0
Global Const MQMDS_FIFO = 1

' Trigger Control
Global Const MQTC_OFF = 0
Global Const MQTC_ON = 1

' Trigger Types
Global Const MQTT_NONE = 0
Global Const MQTT_FIRST = 1
Global Const MQTT_EVERY = 2
Global Const MQTT_DEPTH = 3

' Queue Usage
Global Const MQUS_NORMAL = 0
Global Const MQUS_TRANSMISSION = 1

' Distribution Lists
Global Const MQDL_SUPPORTED = 1
Global Const MQDL_NOT_SUPPORTED = 0

'* Index Type *'
Global Const MQIT_NONE = 0
Global Const MQIT_MSG_ID = 1
Global Const MQIT_CORREL_ID = 2
Global Const MQIT_MSG_TOKEN = 4

'* Archiving Mode *'
Global Const MQAR_NONE = 0
Global Const MQAR_ALL = 1

' Bind Value
Global Const MQBND_BIND_ON_OPEN = 0
Global Const MQBND_BIND_NOT_FIXED = 1

'**********************************************************************'
'*  Values Related to Process-Definition Attributes                   *'
'**********************************************************************'

' Application Types
' See values for "Put Application Types" MQMD


'**********************************************************************'
'*  Values Related to Queue-Manager Attributes                        *'
'**********************************************************************'

'Command Level'
Global Const MQCMDL_LEVEL_1 = 100
Global Const MQCMDL_LEVEL_101 = 101
Global Const MQCMDL_LEVEL_110 = 110
Global Const MQCMDL_LEVEL_114 = 114
Global Const MQCMDL_LEVEL_120 = 120
Global Const MQCMDL_LEVEL_200 = 200
Global Const MQCMDL_LEVEL_201 = 201
Global Const MQCMDL_LEVEL_210 = 210
Global Const MQCMDL_LEVEL_220 = 220
Global Const MQCMDL_LEVEL_221 = 221
Global Const MQCMDL_LEVEL_320 = 320
Global Const MQCMDL_LEVEL_420 = 420
Global Const MQCMDL_LEVEL_500 = 500
Global Const MQCMDL_LEVEL_510 = 510

' Platform
Global Const MQPL_MVS = 1
Global Const MQPL_OS390 = 1
Global Const MQPL_OS2 = 2
Global Const MQPL_AIX = 3
Global Const MQPL_UNIX = 3
Global Const MQPL_OS400 = 4
Global Const MQPL_WINDOWS = 5
Global Const MQPL_WINDOWS_NT = 11
Global Const MQPL_VMS = 12
Global Const MQPL_NSK = 13

' Syncpoint Availability
Global Const MQSP_AVAILABLE = 1
Global Const MQSP_NOT_AVAILABLE = 0

' Channel Auto Definition
Global Const MQCHAD_DISABLED = 0
Global Const MQCHAD_ENABLED = 1

' WLM
Global Const MQWLM_DISABLED = 0
Global Const MQWLM_ENABLED = 1

' Dstribution Lists
' See values for "Distribution Lists" under Queue Attributes

'**********************************************************************'
'*  MQBO Structure -- Begin Options                                   *'
'**********************************************************************'

Type MQBO
   StrucId As String * 4        ' Structure identifier
   Version As Long              ' Version
   Options As Long              ' Controls actions of MQBEGIN
End Type

Global MQBO_DEFAULT As MQBO

'**********************************************************************'
'*  MQCNO Structure -- Connect Options                                *'
'**********************************************************************'

Type MQCNO
   StrucId As String * 4        ' Structure identifier
   Version As Long              ' Version
   Options As Long              ' Controls action of MQCONNX
   ClientConnOffset As Long     ' Offset of MQCD structure for client
                                ' connection
End Type

Global MQCNO_DEFAULT As MQCNO

'**********************************************************************'
'*  MQDH Structure -- Distribution Header                             *'
'**********************************************************************'

Type MQDH
   StrucId         As String * 4    ' Structure identifier
   Version         As Long          ' Structure version number
   StrucLength     As Long          ' Length of MQDH structure plus following records
   Encoding        As Long          ' Encoding of message data
   CodedCharSetId  As Long          ' Coded character-set identifier of message data
   Format          As String * 8    ' Format name of message data
   Flags           As Long          ' Format name of message data
   PutMsgRecFields As Long          ' Flags indicating which MQPMR fields are present
   RecsPresent     As Long          ' Number of object records present
   ObjectRecOffset As Long          ' Offset of first object record from start of MQDH
   PutMsgRecOffset As Long          ' Offset of first put message record from start of MQDH
End Type

Global MQDH_DEFAULT As MQDH

'**********************************************************************'
'*  MQDLH Structure -- Dead Letter Header                             *'
'**********************************************************************'

Type MQDLH
  StrucId        As String * 4   ' Structure identifier'
  Version        As Long         ' Structure version number'
  Reason         As Long         ' Reason message arrived on dead-letter queue'
  DestQName      As String * 48  ' Name of original destination queue
  DestQMgrName   As String * 48  ' Name of original destination queue manager
  Encoding       As Long         ' Original data encoding
  CodedCharSetId As Long         ' Original coded character set identifier
  Format         As String * 8   ' Original format name
  PutApplType    As Long         ' Type of application that put message on dead-letter queue
  PutApplName    As String * 28  ' Name of application that put message on dead-letter queue
  PutDate        As String * 8   ' Date when message was put on dead-letter queue
  PutTime        As String * 8   ' Time when message was put on the dead-letter queue
End Type

Global MQDLH_DEFAULT As MQDLH

'**********************************************************************'
'*  MQGMO Structure -- Get Message Options                            *'
'**********************************************************************'

Type MQGMO
  StrucId       As String * 4   ' Structure identifier
  Version       As Long         ' Structure version number
  Options       As Long         ' Options that control the action of MQGET
  WaitInterval  As Long         ' Wait interval
  Signal1       As Long         ' Signal
  Signal2       As Long         ' Reserved
  ResolvedQName As String * 48  ' Resolved name of destination queue
  MatchOptions  As Long         ' Option for MQGET
  GroupStatus   As String * 1   ' Flag indicating whether message retrieved is in a group
  SegmentStatus As String * 1   ' Flag indicating whether message retrieved is a segment of a logical message
  Segmentation  As String * 1   ' Flag indicating whether further segmentation is allowed for the message retrieved
  Reserved1     As String * 1   ' Reserved
  MsgToken As String * 16       ' Message token
  ReturnedLength As Long        ' Length of message data returned (bytes)
End Type

Global MQGMO_DEFAULT As MQGMO

'IMS Structure not used with NT

'**********************************************************************'
'*  MQMD Structure -- Message Descriptor                              *'
'**********************************************************************'

Type MQMD
  StrucId             As String * 4   ' Structure identifier
  Version             As Long         ' Structure version number
  Report              As Long         ' Report options
  MsgType             As Long         ' Message type
  Expiry              As Long         ' Expiry time
  Feedback            As Long         ' Feedback or reason code
  Encoding            As Long         ' Data encoding
  CodedCharSetId      As Long         ' Coded character set identifier
  Format              As String * 8   ' Format name
  Priority            As Long         ' Message priority
  Persistence         As Long         ' Message persistence
  MsgId               As String * 24  ' Message identifier
  CorrelId            As String * 24  ' Correlation identifier
  BackoutCount        As Long         ' Backout counter
  ReplyToQ            As String * 48  ' Name of reply-to queue
  ReplyToQMgr         As String * 48  ' Name of reply queue manager
  UserIdentifier      As String * 12  ' User identifier
  AccountingToken     As String * 32  ' Accounting token
  ApplIdentityData    As String * 32  ' Application data relating to identity
  PutApplType         As Long         ' Type of application that put the message
  PutApplName         As String * 28  ' Name of application that put the message
  PutDate             As String * 8   ' Date when message was put
  PutTime             As String * 8   ' Time when message was put
  ApplOriginData      As String * 4   ' Application data relating to origin
  GroupId             As String * 24  ' Group identifier
  MsgSeqNumber        As Long         ' Sequence number withing group
  Offset              As Long         ' Offset of data in phsyical message from start of logical message
  MsgFlags            As Long         ' Message flags
  OriginalLength      As Long         ' Length of original message
End Type

Global MQMD_DEFAULT As MQMD

'**********************************************************************'
'*  MQMDE Structure -- Message descriptor extension                   *'
'**********************************************************************'

Type MQMDE
   StrucId        As String * 4  ' Structure identifier
   Version        As Long        ' Structure version number
   StrucLength    As Long        ' Length of MQMDE structure
   Encoding       As Long        ' Encoding of message data
   CodedCharSetId As Long        ' Coded character set ID of message data
   Format         As String * 8  ' Format name of message data
   Flags          As Long        ' General flags
   GroupId        As String * 24 ' Group identifier
   MsgSeqNumber   As Long        ' Sequence number of logical messages within group
   Offset         As Long        ' Offset of data in physical message from start of logical message
   MsgFlags       As Long        ' Message flags
   OriginalLength As Long        ' Length of original message
End Type

Global MQMDE_DEFAULT As MQMDE

'**********************************************************************'
'*  MQMD1 Structure -- Version 1 Message Descriptor                   *'
'**********************************************************************'

Type MQMD1
   StrucId          As String * 4    ' Structure identifier
   Version          As Long          ' Structure version number
   Report           As Long          ' Report options
   MsgType          As Long          ' Message type
   Expiry           As Long          ' Expiry time
   Feedback         As Long          ' Feedback or reason code
   Encoding         As Long          ' Data encoding
   CodedCharSetId   As Long          ' Coded character set identifier
   Format           As String * 8    ' Format name
   Priority         As Long          ' Message priority
   Persistence      As Long          ' Message persistance
   MsgId            As String * 24   ' Message identifier
   CorrelId         As String * 24   ' Correlation identifier
   BackoutCount     As Long          ' Backout counter
   ReplyToQ         As String * 48   ' Name of reply queue
   ReplyToQMgr      As String * 48   ' Name of reply queue manager
   UserIdentifier   As String * 12   ' User identifier
   AccountingToken  As String * 32   ' Accounting token
   ApplIdentityData As String * 32   ' Application data
   PutApplType      As Long          ' Type of application that put the message
   PutApplName      As String * 28   ' Name of application that put the message
   PutDate          As String * 8    ' Date when message was put
   PutTime          As String * 8    ' Time when message was put
   ApplOriginData   As String * 4    ' Application data relating to origin
End Type

Global MQMD1_DEFAULT As MQMD1

'**********************************************************************'
'*  MQOD Structure -- Object Descriptor                               *'
'**********************************************************************'

Type MQOD
  StrucId             As String * 4    ' Structure identifier
  Version             As Long          ' Structure version number
  ObjectType          As Long          ' Object type
  ObjectName          As String * 48   ' Object name
  ObjectQMgrName      As String * 48   ' Object queue manager name
  DynamicQName        As String * 48   ' Dynamic queue name
  AlternateUserId     As String * 12   ' Alternate user identifier
  RecsPresent         As Long          ' Number of object records present
  KnownDestCount      As Long          ' Number of local queues opened successfully
  UnknownDestCount    As Long          ' Number of remote queues opened successfully
  InvalidDestCount    As Long          ' Number of queues that failed to open
  ObjectRecOffset     As Long          ' Offset of first object recoed from start of MQOD
  ResponseRecOffset   As Long          ' Offset of first response record from start of MQOD
  ObjectRecPtr        As String * 32   ' Address of first object record
  ResponseRecPtr      As String * 32   ' Address of first response record
  AlternateSecurityId As String * 40   ' Alternate security identifier
  ResolvedQName       As String * 48   ' Resolved queue name
  ResolvedQMgrName    As String * 48   ' Resolved queue manager name
End Type

Global MQOD_DEFAULT As MQOD

'**********************************************************************'
'*  MQOR Structure -- Object Record                                   *'
'**********************************************************************'

Type MQOR
   ObjectName     As String * 48       ' Object name
   ObjectQMgrName As String * 48       ' Object queue manager name
End Type

Global MQOR_DEFAULT As MQOR

'**********************************************************************'
'*  MQPMO Structure -- Put Message Options                            *'
'**********************************************************************'

Type MQPMO
  StrucId           As String * 4   ' Structure identifier
  Version           As Long         ' Structure version number
  Options           As Long         ' Options that control the action of MQPUT or MQPUT
  Timeout           As Long         ' Reserved
  Context           As Long         ' Object handle of input queue
  KnownDestCount    As Long         ' Reserved
  UnknownDestCount  As Long         ' Reserved
  InvalidDestCount  As Long         ' Reserved
  ResolvedQName     As String * 48  ' Resolved name of destination queue
  ResolvedQMgrName  As String * 48  ' Resolved name of destination queue manager
  RecsPresent       As Long         ' Number of put message records or response records present
  PutMsgRecFields   As Long         ' Flags indicating which MQPMR fields are present
  PutMsgRecOffset   As Long         ' Offset of first put message record from start of MQPMO
  ResponseRecOffset As Long         ' Offset of first response record from start of MQMO
  PutMsgRecPtr      As String * 32  ' Reserved
  ResponseRecPtr    As String * 32  ' Reserved
End Type

Global MQPMO_DEFAULT As MQPMO

'**********************************************************************'
'*  MQPMR Structure -- Put Message Record                             *'
'**********************************************************************'

Type MQPMR
  MsgId           As String * 24  ' Message Identifier
  CorrelId        As String * 24  ' Correlation identifier
  Feedback        As Long         ' Feedback or reason code
  AccountingToken As String * 32  ' Accounting token
End Type

Global MQPMR_DEFAULT As MQPMR

'*********************************************************************'
'*  MQRFH Structure -- Rules and Formatting Header                   *'
'*********************************************************************'

Type MQRFH 
   StrucId        As String *4 ' Structure identifier
   Version        As Long      ' Structure version number 
   StrucLength    As Long      ' Total length of MQRFH including string
                               '   containing name/value pairs 
   Encoding       As Long      ' Numeric encoding of data that follows
                               '   NameValueString 
   CodedCharSetId As Long      ' Character set identifier of data that
                               ' follows NameValueString 
   Format         As String*8  ' Format name of data that follows
                               ' NameValueString 
   Flags          As long      ' Flags 
End Type

Global MQRFH_DEFAULT As MQRFH

 
'**********************************************************************'
'*  MQRMH Structure -- Reference Message Header                       *'
'**********************************************************************'

Type MQRMH
   StrucId            As String * 4  ' Structure identifier
   Version            As Long        ' Version
   StrucLength        As Long        ' Total length of MQRMH
   Encoding           As Long        ' Data encoding
   CodedCharSetId     As Long        ' Coded character set identifier
   Format             As String * 8  ' Format name
   Flags              As Long        ' Reference message flags
   ObjectType         As String * 8  ' object type
   ObjectInstanceId   As String * 24 ' Object instance identifier
   SrcEnvLength       As Long        ' Length of source object name
   SrcNameOffset      As Long        ' Offset of source object name
   DestEnvLength      As Long        ' Length of destination environment data
   DestEnvOffset      As Long        ' Offset of destination environment data
   DestNameLength     As Long        ' Length of destination object name
   DestNameOffset     As Long        ' Offset of destination object name
   DataLogicalLength  As Long        ' Length of bulk data
   DataLogicalOffset  As Long        ' Low offset of bulk data
   DataLogicalOffset2 As Long        ' High offset of bulk data
End Type

Global MQRMH_DEFAULT As MQRMH

'**********************************************************************'
'*  MQRR Structure -- Response Record                                 *'
'**********************************************************************'

Type MQRR
   CompCode As Long    ' Completion code for queue
   Reason As Long      ' Reason code for queue
End Type

Global MQRR_DEFAULT As MQRR

'**********************************************************************'
'*  MQTM Structure -- Trigger Message                                 *'
'**********************************************************************'

Type MQTM
  StrucId     As String * 4      ' Structure identifier
  Version     As Long            ' Structure version number
  QName       As String * 48     ' Name of triggered queue
  ProcessName As String * 48     ' Name of process object
  TriggerData As String * 64     ' Trigger data
  ApplType    As Long            ' Application type
  ApplId      As String * 256    ' Application identifier
  EnvData     As String * 128    ' Environment data
  UserData    As String * 128    ' User data
End Type

Global MQTM_DEFAULT As MQTM

'**********************************************************************'
'*  MQTMC2 Structure -- Trigger Message 2 (Character)                 *'
'**********************************************************************'

Type MQTMC2
  StrucId     As String * 4     'Structure identifier
  Version     As String * 4     'Structure version number
  QName       As String * 48    'Name of triggered queue
  ProcessName As String * 48    'Name of process object
  TriggerData As String * 64    'Trigger data
  ApplType    As String * 4     'Application type
  ApplId      As String * 256   'Application identifier
  EnvData     As String * 128   'Environment data
  UserData    As String * 128   'User data
  QMgrName    As String * 48    'Queue manager name
End Type

Global MQTMC2_DEFAULT As MQTMC2

'**********************************************************************'
'*  MQXQH Structure -- Transmission Queue Header                      *'
'**********************************************************************'

Type MQXQH
  StrucId        As String * 4   ' Structure identifier
  Version        As Long         ' Structure version number
  RemoteQName    As String * 48  ' Name of destination queue
  RemoteQMgrName As String * 48  ' Name of destination queue manager
  MsgDesc        As MQMD1        ' Original message descriptor
End Type

Global MQXQH_DEFAULT As MQXQH

'**********************************************************************'
'*  MQNL Structure -- Namelist File Structure                         *'
'**********************************************************************'

Type MQNL
   StrucId  As String * 4                      ' Structure identifier
   Version  As Long                            ' Structure version name
   NlDesc   As String * 64                     ' Namelist description
   Names    As String * MQ_NL_NAMES_LENGTH     ' Name stored in namelist
   NamCount As Long                            ' Number of names stored in namelist
End Type

Global MQNL_DEFAULT As MQNL


' Visual Basic Dynamic Link Library Names
#If MqType = 1 Then ' server
  Global Const MQVBDLL = "MQM.DLL"

  ' Standard MQ functions called directly from user's application
  Declare Sub MQBACK Lib "MQM.DLL" Alias "MQBACKstd@12" (ByVal Hconn As Long, CompCode As Long, Reason As Long)
  Declare Sub MQBEGIN Lib "MQM.DLL" Alias "MQBEGINstd@16" (ByVal Hconn As Long, BeginOptions As MQBO, CompCode As Long, Reason As Long)
  Declare Sub MQCLOSE Lib "MQM.DLL" Alias "MQCLOSEstd@20" (ByVal Hconn As Long, Hobj As Long, ByVal Options As Long, CompCode As Long, Reason As Long)
  Declare Sub MQCMIT Lib "MQM.DLL" Alias "MQCMITstd@12" (ByVal Hconn As Long, CompCode As Long, Reason As Long)
  Declare Sub MQCONN Lib "MQM.DLL" Alias "MQCONNstd@16" (ByVal QMgrName As String * 48, Hconn As Long, CompCode As Long, Reason As Long)
  Declare Sub MQCONNX Lib "MQM.DLL" Alias "MQCONNXstd@20" (ByVal QMgrName As String * 48, ConnectOpts As MQCNO, Hconn As Long, CompCode As Long, Reason As Long)
  Declare Sub MQDISC Lib "MQM.DLL" Alias "MQDISCstd@12" (Hconn As Long, CompCode As Long, Reason As Long)
  Declare Sub MQOPEN Lib "MQM.DLL" Alias "MQOPENstd@24" (ByVal Hconn As Long, ObjDesc As MQOD, ByVal Options As Long, Hobj As Long, CompCode As Long, Reason As Long)

  ' Alternative form of MQ functions called directly from user's application
  Declare Sub MQGETAny Lib "MQM.DLL" Alias "MQGETstd@36" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, ByVal BufferLength As Long, Buffer As Any, DataLength As Long, CompCode As Long, Reason As Long)
  Declare Sub MQPUTAny Lib "MQM.DLL" Alias "MQPUTstd@32" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, Buffer As Any, CompCode As Long, Reason As Long)
  Declare Sub MQPUT1Any Lib "MQM.DLL" Alias "MQPUT1std@32" (ByVal Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, Buffer As Any, CompCode As Long, Reason As Long)

  ' private functions accessed via "safe" versions such as MQGET
  Private Declare Sub MQINQX Lib "MQM.DLL" Alias "MQINQstd@40" (ByVal Hconn As Long, ByVal Hobj As Long, ByVal SelectorCount As Long, Selectors As Long, ByVal intAttrCount As Long, intAttrs As Long, ByVal CharAttrLength As Long, ByVal CharAttrs As String, CompCode As Long, Reason As Long)
  Private Declare Sub MQGETX Lib "MQM.DLL" Alias "MQGETstd@36" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, ByVal BufferLength As Long, ByVal Buffer As String, DataLength As Long, CompCode As Long, Reason As Long)
  Private Declare Sub MQPUTX Lib "MQM.DLL" Alias "MQPUTstd@32" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, ByVal Buffer As String, CompCode As Long, Reason As Long)
  Private Declare Sub MQPUT1X Lib "MQM.DLL" Alias "MQPUT1std@32" (ByVal Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, ByVal Buffer As String, CompCode As Long, Reason As Long)
  Private Declare Sub MQSETX Lib "MQM.DLL" Alias "MQSETstd@40" (ByVal Hconn As Long, ByVal Hobj As Long, ByVal SelectorCount As Long, Selectors As Long, ByVal intAttrCount As Long, intAttrs As Long, ByVal CharAttrLength As Long, ByVal CharAttrs As String, CompCode As Long, Reason As Long)
#ElseIf MqType = 2 Then ' client
  #If Win16 Then
    Global Const MQVBDLL = "MQIC.DLL"
    
    ' Standard MQ functions called directly from user's application
    Declare Sub MQBACK Lib "MQIC.DLL" (ByVal Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQBEGIN Lib "MQIC.DLL" (ByVal Hconn As Long, BeginOptions As MQBO, CompCode As Long, Reason As Long)
    Declare Sub MQCLOSE Lib "MQIC.DLL" (ByVal Hconn As Long, Hobj As Long, ByVal Options As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCMIT Lib "MQIC.DLL" (ByVal Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCONN Lib "MQIC.DLL" (ByVal QMgrName As String * 48, Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCONNX Lib "MQIC.DLL" (ByVal QMgrName As String * 48, ConnectOpts As MQCNO, Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQDISC Lib "MQIC.DLL" (Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQOPEN Lib "MQIC.DLL" (ByVal Hconn As Long, ObjDesc As MQOD, ByVal Options As Long, Hobj As Long, CompCode As Long, Reason As Long)
    
    ' Alternative form of MQ functions called directly from user's application
    Declare Sub MQGETAny Lib "MQIC.DLL" Alias "MQGET" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, ByVal BufferLength As Long, Buffer As Any, DataLength As Long, CompCode As Long, Reason As Long)
    Declare Sub MQPUTAny Lib "MQIC.DLL" Alias "MQPUT" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, Buffer As Any, CompCode As Long, Reason As Long)
    Declare Sub MQPUT1Any Lib "MQIC.DLL" Alias "MQPUT1" (ByVal Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, Buffer As Any, CompCode As Long, Reason As Long)
    
    ' private functions accessed via "safe" versions such as MQGET
    Private Declare Sub MQINQX Lib "MQIC.DLL" Alias "MQINQ" (ByVal Hconn As Long, ByVal Hobj As Long, ByVal SelectorCount As Long, Selectors As Long, ByVal intAttrCount As Long, intAttrs As Long, ByVal CharAttrLength As Long, ByVal CharAttrs As String, CompCode As Long, Reason As Long)
    Private Declare Sub MQGETX Lib "MQIC.DLL" Alias "MQGET" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, ByVal BufferLength As Long, ByVal Buffer As String, DataLength As Long, CompCode As Long, Reason As Long)
    Private Declare Sub MQPUTX Lib "MQIC.DLL" Alias "MQPUT" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, ByVal Buffer As String, CompCode As Long, Reason As Long)
    Private Declare Sub MQPUT1X Lib "MQIC.DLL" Alias "MQPUT1" (ByVal Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, ByVal Buffer As String, CompCode As Long, Reason As Long)
    Private Declare Sub MQSETX Lib "MQIC.DLL" Alias "MQSET" (ByVal Hconn As Long, ByVal Hobj As Long, ByVal SelectorCount As Long, Selectors As Long, ByVal intAttrCount As Long, intAttrs As Long, ByVal CharAttrLength As Long, ByVal CharAttrs As String, CompCode As Long, Reason As Long)
  #ElseIf Win32 Then
     Global Const MQVBDLL = "MQIC32.DLL"

    ' Standard MQ functions called directly from user's application
    Declare Sub MQBACK Lib "MQIC32.DLL" Alias "MQBACKstd@12" (ByVal Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQBEGIN Lib "MQIC32.DLL" Alias "MQBEGINstd@16" (ByVal Hconn As Long, ByVal BeginOptions As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCLOSE Lib "MQIC32.DLL" Alias "MQCLOSEstd@20" (ByVal Hconn As Long, Hobj As Long, ByVal Options As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCMIT Lib "MQIC32.DLL" Alias "MQCMITstd@12" (ByVal Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCONN Lib "MQIC32.DLL" Alias "MQCONNstd@16" (ByVal QMgrName As String * 48, Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQCONNX Lib "MQIC32.DLL" Alias "MQCONNXstd@20" (ByVal QMgrName As String * 48, ConnectOpts As MQCNO, Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQDISC Lib "MQIC32.DLL" Alias "MQDISCstd@12" (Hconn As Long, CompCode As Long, Reason As Long)
    Declare Sub MQOPEN Lib "MQIC32.DLL" Alias "MQOPENstd@24" (ByVal Hconn As Long, ObjDesc As MQOD, ByVal Options As Long, Hobj As Long, CompCode As Long, Reason As Long)
  
    ' Alternative form of MQ functions called directly from user's application
    Declare Sub MQGETAny Lib "MQIC32.DLL" Alias "MQGETstd@36" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, ByVal BufferLength As Long, Buffer As Any, DataLength As Long, CompCode As Long, Reason As Long)
    Declare Sub MQPUTAny Lib "MQIC32.DLL" Alias "MQPUTstd@32" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, Buffer As Any, CompCode As Long, Reason As Long)
    Declare Sub MQPUT1Any Lib "MQIC32.DLL" Alias "MQPUT1std@32" (ByVal Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, Buffer As Any, CompCode As Long, Reason As Long)
  
    ' private functions accessed via "safe" versions such as MQGET
    Private Declare Sub MQINQX Lib "MQIC32.DLL" Alias "MQINQstd@40" (ByVal Hconn As Long, ByVal Hobj As Long, ByVal SelectorCount As Long, Selectors As Long, ByVal intAttrCount As Long, intAttrs As Long, ByVal CharAttrLength As Long, ByVal CharAttrs As String, CompCode As Long, Reason As Long)
    Private Declare Sub MQGETX Lib "MQIC32.DLL" Alias "MQGETstd@36" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, ByVal BufferLength As Long, ByVal Buffer As String, DataLength As Long, CompCode As Long, Reason As Long)
    Private Declare Sub MQPUTX Lib "MQIC32.DLL" Alias "MQPUTstd@32" (ByVal Hconn As Long, ByVal Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, ByVal Buffer As String, CompCode As Long, Reason As Long)
    Private Declare Sub MQPUT1X Lib "MQIC32.DLL" Alias "MQPUT1std@32" (ByVal Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, ByVal BufferLength As Long, ByVal Buffer As String, CompCode As Long, Reason As Long)
    Private Declare Sub MQSETX Lib "MQIC32.DLL" Alias "MQSETstd@40" (ByVal Hconn As Long, ByVal Hobj As Long, ByVal SelectorCount As Long, Selectors As Long, ByVal intAttrCount As Long, intAttrs As Long, ByVal CharAttrLength As Long, ByVal CharAttrs As String, CompCode As Long, Reason As Long)
  #End If
#Else
  Global Const MQVBDLL = "NONE"
  ' MqType not set or set wrong.
  ' Please see the comments at the top of this file
#End If

'**********************************************************************'
'*  MQBO_DEFAULTS Subroutine -- Initialise MQBO to default values     *'
'**********************************************************************'
Sub MQBO_DEFAULTS(Struc As MQBO)
  Struc.StrucId = MQBO_STRUC_ID
  Struc.Version = MQBO_VERSION_1
  Struc.Options = MQBO_NONE
End Sub

'**********************************************************************'
'*  MQCNO_DEFAULTS Subroutine -- Initialise MQCNO to default values   *'
'**********************************************************************'
Sub MQCNO_DEFAULTS(Struc As MQCNO)
  Struc.StrucId = MQCNO_STRUC_ID
  Struc.Version = MQCNO_VERSION_1
  Struc.Options = MQCNO_NONE
  Struc.ClientConnOffset = 0
End Sub

'**********************************************************************'
'*  MQDH_DEFAULTS Subroutine -- Initialise MQDH to default values     *'
'**********************************************************************'
Sub MQDH_DEFAULTS(Struc As MQDH)
  Struc.StrucId = MQDH_STRUC_ID
  Struc.Version = MQDH_VERSION_1
  Struc.StrucLength = 0
  Struc.Encoding = 0
  Struc.CodedCharSetId = 0
  Struc.Format = MQFMT_NONE
  Struc.Flags = MQDHF_NONE
  Struc.PutMsgRecFields = MQPMRF_NONE
  Struc.RecsPresent = 0
  Struc.ObjectRecOffset = 0
  Struc.PutMsgRecOffset = 0
End Sub

'**********************************************************************'
'*  MQDLH_DEFAULTS Subroutine -- Initialise MQDLH to default values   *'
'**********************************************************************'
Sub MQDLH_DEFAULTS(Struc As MQDLH)
  Struc.StrucId = MQDLH_STRUC_ID
  Struc.Version = MQDLH_VERSION_1
  Struc.Reason = MQRC_NONE
  Struc.DestQName = ""
  Struc.DestQMgrName = ""
  Struc.Encoding = 0
  Struc.CodedCharSetId = 0
  Struc.Format = MQFMT_NONE
  Struc.PutApplType = 0
  Struc.PutApplName = ""
  Struc.PutDate = ""
  Struc.PutTime = ""
End Sub

'**********************************************************************'
'*  MQGMO_DEFAULTS Subroutine -- Initialise MQGMO to default values   *'
'**********************************************************************'
Sub MQGMO_DEFAULTS(Struc As MQGMO)
  Struc.StrucId = MQGMO_STRUC_ID
  Struc.Version = MQGMO_VERSION_1
  Struc.Options = MQGMO_NO_WAIT
  Struc.WaitInterval = 0
  Struc.Signal1 = 0
  Struc.Signal2 = 0
  Struc.ResolvedQName = ""
  Struc.MatchOptions = MQMO_MATCH_MSG_ID + MQMO_MATCH_CORREL_ID
  Struc.GroupStatus = MQGS_NOT_IN_GROUP
  Struc.SegmentStatus = MQSS_NOT_A_SEGMENT
  Struc.Segmentation = MQSEG_INHIBITED
  Struc.Reserved1 = " "
  Struc.MsgToken = MQMTOK_NONE
  Struc.ReturnedLength = MQRL_UNDEFINED
End Sub

'**********************************************************************'
'*  MQMD_DEFAULTS Subroutine -- Initialise MQMD to default values     *'
'**********************************************************************'
Sub MQMD_DEFAULTS(Struc As MQMD)
  Struc.StrucId = MQMD_STRUC_ID
  Struc.Version = MQMD_VERSION_1
  Struc.Report = MQRO_NONE
  Struc.MsgType = MQMT_DATAGRAM
  Struc.Expiry = MQEI_UNLIMITED
  Struc.Feedback = MQFB_NONE
  Struc.Encoding = MQENC_NATIVE
  Struc.CodedCharSetId = MQCCSI_Q_MGR
  Struc.Format = MQFMT_NONE
  Struc.Priority = MQPRI_PRIORITY_AS_Q_DEF
  Struc.Persistence = MQPER_PERSISTENCE_AS_Q_DEF
  Struc.MsgId = String(24, 0)
  Struc.CorrelId = String(24, 0)
  Struc.BackoutCount = 0
  Struc.ReplyToQ = ""
  Struc.ReplyToQMgr = ""
  Struc.UserIdentifier = ""
  Struc.AccountingToken = String(32, 0)
  Struc.ApplIdentityData = ""
  Struc.PutApplType = MQAT_NO_CONTEXT
  Struc.PutApplName = ""
  Struc.PutDate = ""
  Struc.PutTime = ""
  Struc.ApplOriginData = ""
  Struc.GroupId = MQGI_NONE
  Struc.MsgSeqNumber = 1
  Struc.Offset = 0
  Struc.MsgFlags = MQMF_NONE
  Struc.OriginalLength = MQOL_UNDEFINED
End Sub

'**********************************************************************'
'*  MQMD1_DEFAULTS Subroutine -- Initialise MQMD1 to default values   *'
'**********************************************************************'
Sub MQMD1_DEFAULTS(Struc As MQMD1)
  Struc.StrucId = MQMD_STRUC_ID
  Struc.Version = MQMD_VERSION_1
  Struc.Report = MQRO_NONE
  Struc.MsgType = MQMT_DATAGRAM
  Struc.Expiry = MQEI_UNLIMITED
  Struc.Feedback = MQFB_NONE
  Struc.Encoding = MQENC_NATIVE
  Struc.CodedCharSetId = MQCCSI_Q_MGR
  Struc.Format = MQFMT_NONE
  Struc.Priority = MQPRI_PRIORITY_AS_Q_DEF
  Struc.Persistence = MQPER_PERSISTENCE_AS_Q_DEF
  Struc.MsgId = MQMI_NONE
  Struc.CorrelId = MQCI_NONE
  Struc.BackoutCount = 0
  Struc.ReplyToQ = ""
  Struc.ReplyToQMgr = ""
  Struc.UserIdentifier = ""
  Struc.AccountingToken = MQACT_NONE
  Struc.ApplIdentityData = ""
  Struc.PutApplType = MQAT_NO_CONTEXT
  Struc.PutApplName = ""
  Struc.PutDate = ""
  Struc.PutTime = ""
  Struc.ApplOriginData = ""
End Sub


'**********************************************************************'
'*  MQMDE_DEFAULTS Subroutine -- Initialise MQMDE to default values   *'
'**********************************************************************'
Sub MQMDE_DEFAULTS(Struc As MQMDE)
  Struc.StrucId = MQMDE_STRUC_ID
  Struc.Version = MQMDE_VERSION_2
  Struc.StrucLength = MQMDE_LENGTH_2
  Struc.Encoding = MQENC_NATIVE
  Struc.CodedCharSetId = 0
  Struc.Format = MQFMT_NONE
  Struc.Flags = MQMDEF_NONE
  Struc.GroupId = MQGI_NONE
  Struc.MsgSeqNumber = 1
  Struc.Offset = 0
  Struc.MsgFlags = MQMF_NONE
  Struc.OriginalLength = MQOL_UNDEFINED
End Sub

'**********************************************************************'
'*  MQNL_DEFAULTS Subroutine -- Initialise MQNL to default values     *'
'**********************************************************************'
Sub MQNL_DEFAULTS(Struc As MQNL)
  Struc.StrucId = MQNL_STRUC_ID
  Struc.Version = MQNL_VERSION_1
  Struc.NlDesc = ""
  Struc.Names = ""
  Struc.NamCount = 0
End Sub

'**********************************************************************'
'*  MQOD_DEFAULTS Subroutine -- Initialise MQOD to default values     *'
'**********************************************************************'
Sub MQOD_DEFAULTS(Struc As MQOD)
  Struc.StrucId = MQOD_STRUC_ID
  Struc.Version = MQOD_VERSION_1
  Struc.ObjectType = MQOT_Q
  Struc.ObjectName = ""
  Struc.ObjectQMgrName = ""
  Struc.DynamicQName = "AMQ.*"
  Struc.AlternateUserId = ""
  Struc.RecsPresent = 0
  Struc.KnownDestCount = 0
  Struc.UnknownDestCount = 0
  Struc.InvalidDestCount = 0
  Struc.ObjectRecOffset = 0
  Struc.ResponseRecOffset = 0
  Struc.ObjectRecPtr = String(32, 0)
  Struc.ResponseRecPtr = String(32, 0)
  Struc.AlternateSecurityId = MQSID_NONE
  Struc.ResolvedQName = ""
  Struc.ResolvedQMgrName = ""
End Sub

'**********************************************************************'
'*  MQOR_DEFAULTS Subroutine -- Initialise MQOR to default values     *'
'**********************************************************************'
Sub MQOR_DEFAULTS(Struc As MQOR)
  Struc.ObjectName = ""
  Struc.ObjectQMgrName = ""
End Sub

'**********************************************************************'
'*  MQPMO_DEFAULTS Subroutine -- Initialise MQPMO to default values   *'
'**********************************************************************'
Sub MQPMO_DEFAULTS(Struc As MQPMO)
  Struc.StrucId = MQPMO_STRUC_ID
  Struc.Version = MQPMO_VERSION_1
  Struc.Options = MQPMO_NONE
  Struc.Timeout = -1
  Struc.Context = 0
  Struc.KnownDestCount = 0
  Struc.UnknownDestCount = 0
  Struc.InvalidDestCount = 0
  Struc.ResolvedQName = ""
  Struc.ResolvedQMgrName = ""
  Struc.RecsPresent = 0
  Struc.PutMsgRecFields = MQPMRF_NONE
  Struc.PutMsgRecOffset = 0
  Struc.ResponseRecOffset = 0
  Struc.PutMsgRecPtr = String(32, 0)
  Struc.ResponseRecPtr = String(32, 0)
End Sub

'**********************************************************************'
'*  MQRFH_DEFAULTS Subroutine -- Initialise MQRFH to default values   *'
'**********************************************************************'
Sub MQRFH_DEFAULTS(Struc As MQRFH)
  Struc.StrucId = MQRFH_STRUC_ID
  Struc.Version = MQRFH_VERSION_1
  Struc.StrucLength = MQRFH_STRUC_LENGTH_FIXED
  Struc.Encoding = MQENC_NATIVE
  Struc.CodedCharSetId = 0
  Struc.Format = MQFMT_NONE
  Struc.Flags = MQRFH_NONE
End Sub

'**********************************************************************'
'*  MQRMH_DEFAULTS Subroutine -- Initialise MQRMH to default values   *'
'**********************************************************************'
Sub MQRMH_DEFAULTS(Struc As MQRMH)
  Struc.StrucId = MQRMH_STRUC_ID
  Struc.Version = MQRMH_VERSION_1
  Struc.StrucLength = 0
  Struc.Encoding = MQENC_NATIVE
  Struc.CodedCharSetId = 0
  Struc.Format = MQFMT_NONE
  Struc.Flags = MQRMHF_NOT_LAST
  Struc.ObjectType = "        "
  Struc.ObjectInstanceId = MQOII_NONE
  Struc.SrcEnvLength = 0
  Struc.SrcNameOffset = 0
  Struc.DestEnvLength = 0
  Struc.DestEnvOffset = 0
  Struc.DestNameLength = 0
  Struc.DestNameOffset = 0
  Struc.DataLogicalLength = 0
  Struc.DataLogicalOffset = 0
  Struc.DataLogicalOffset2 = 0
End Sub

'**********************************************************************'
'*  MQRR_DEFAULTS Subroutine -- Initialise MQRR to default values     *'
'**********************************************************************'
Sub MQRR_DEFAULTS(Struc As MQRR)
  Struc.CompCode = MQCC_OK
  Struc.Reason = MQRC_NONE
End Sub

'**********************************************************************'
'*  MQTM_DEFAULTS Subroutine -- Initialise MQTM to default values     *'
'**********************************************************************'
Sub MQTM_DEFAULTS(Struc As MQTM)
  Struc.StrucId = MQTM_STRUC_ID
  Struc.Version = MQTM_VERSION_1
  Struc.QName = ""
  Struc.ProcessName = ""
  Struc.TriggerData = ""
  Struc.ApplType = 0
  Struc.ApplId = ""
  Struc.EnvData = ""
  Struc.UserData = ""
End Sub

'**********************************************************************'
'*  MQTMC2_DEFAULTS Subroutine -- Initialise MQTMC2 to default values *'
'**********************************************************************'
Sub MQTMC2_DEFAULTS(Struc As MQTMC2)
  Struc.StrucId = MQTMC_STRUC_ID
  Struc.Version = MQTMC_VERSION_2
  Struc.QName = ""
  Struc.ProcessName = ""
  Struc.TriggerData = ""
  Struc.ApplType = ""
  Struc.ApplId = ""
  Struc.EnvData = ""
  Struc.UserData = ""
  Struc.QMgrName = ""
End Sub

'**********************************************************************'
'*  MQXQH_DEFAULTS Subroutine -- Initialise MQXQH to default values   *'
'**********************************************************************'
Sub MQXQH_DEFAULTS(Struc As MQXQH)
  Struc.StrucId = MQXQH_STRUC_ID
  Struc.Version = MQXQH_VERSION_1
  Struc.RemoteQName = ""
  Struc.RemoteQMgrName = ""
  Dim md As MQMD1
  MQMD1_DEFAULTS md
  Struc.MsgDesc = md
End Sub

'**********************************************************************'
'*  MQ_SETDEFAULTS Subroutine -- Initialise default structures        *'
'**********************************************************************'
Sub MQ_SETDEFAULTS()
  ' Check that MQType has been set
  If MQVBDLL = "NONE" Then
    MsgBox "MQType has not been set correctly" & Chr(10) & Chr(13) & "Please see the comments at the start of CMQB.BAS", vbOKOnly + vbExclamation, "Error"
    End
  End If
  MQCFAC_NONE = String(8, 0)
  MQITII_NONE = String(16, 0)
  MQMI_NONE = String(24, 0)
  MQCI_NONE = String(24, 0)
  MQACT_NONE = String(32, 0)
  MQGI_NONE = String(24, 0)
  MQOII_NONE = String(24, 0)
  MQMTOK_NONE = String(16, 0)
  MQSID_NONE = String(40, 0)
  
  MQBO_DEFAULTS MQBO_DEFAULT
  MQCNO_DEFAULTS MQCNO_DEFAULT
  MQDH_DEFAULTS MQDH_DEFAULT
  MQDLH_DEFAULTS MQDLH_DEFAULT
  MQGMO_DEFAULTS MQGMO_DEFAULT
  MQMD_DEFAULTS MQMD_DEFAULT
  MQMD1_DEFAULTS MQMD1_DEFAULT
  MQMDE_DEFAULTS MQMDE_DEFAULT
  MQNL_DEFAULTS MQNL_DEFAULT
  MQOD_DEFAULTS MQOD_DEFAULT
  MQOR_DEFAULTS MQOR_DEFAULT
  MQPMO_DEFAULTS MQPMO_DEFAULT
  MQRFH_DEFAULTS MQRFH_DEFAULT
  MQRMH_DEFAULTS MQRMH_DEFAULT
  MQRR_DEFAULTS MQRR_DEFAULT
  MQTM_DEFAULTS MQTM_DEFAULT
  MQTMC2_DEFAULTS MQTMC2_DEFAULT
  MQXQH_DEFAULTS MQXQH_DEFAULT

End Sub


Sub MQGET(Hconn As Long, Hobj As Long, MsgDesc As MQMD, GetMsgOpts As MQGMO, BufferLength As Long, Buffer As String, DataLength As Long, CompCode As Long, Reason As Long)
  If BufferLength > LenB(Buffer) Then
    CompCode = MQCC_FAILED
    Reason = MQRC_BUFFER_LENGTH_ERROR
  Else
    MQGETX Hconn, Hobj, MsgDesc, GetMsgOpts, BufferLength, Buffer, DataLength, CompCode, Reason
  End If
End Sub

Sub MQINQ(Hconn As Long, Hobj As Long, SelectorCount As Long, Selectors As Long, intAttrCount As Long, intAttrs As Long, CharAttrLength As Long, CharAttrs As String, CompCode As Long, Reason As Long)
  If CharAttrLength > LenB(CharAttrs) Then
    CompCode = MQCC_FAILED
    Reason = MQRC_BUFFER_LENGTH_ERROR
  Else
    MQINQX Hconn, Hobj, SelectorCount, Selectors, intAttrCount, intAttrs, CharAttrLength, CharAttrs, CompCode, Reason
  End If
End Sub


Sub MQPUT(Hconn As Long, Hobj As Long, MsgDesc As MQMD, PutMsgOpts As MQPMO, BufferLength As Long, Buffer As String, CompCode As Long, Reason As Long)
  If BufferLength > LenB(Buffer) Then
    CompCode = MQCC_FAILED
    Reason = MQRC_BUFFER_LENGTH_ERROR
  Else
    MQPUTX Hconn, Hobj, MsgDesc, PutMsgOpts, BufferLength, Buffer, CompCode, Reason
  End If
End Sub

Sub MQPUT1(Hconn As Long, ObjDesc As MQOD, MsgDesc As MQMD, PutMsgOpts As MQPMO, BufferLength As Long, Buffer As String, CompCode As Long, Reason As Long)
  If BufferLength > LenB(Buffer) Then
    CompCode = MQCC_FAILED
    Reason = MQRC_BUFFER_LENGTH_ERROR
  Else
    MQPUT1X Hconn, ObjDesc, MsgDesc, PutMsgOpts, BufferLength, Buffer, CompCode, Reason
  End If
End Sub

Sub MQSET(Hconn As Long, Hobj As Long, SelectorCount As Long, Selectors As Long, intAttrCount As Long, intAttrs As Long, CharAttrLength As Long, CharAttrs As String, CompCode As Long, Reason As Long)
  If CharAttrLength > LenB(CharAttrs) Then
    CompCode = MQCC_FAILED
    Reason = MQRC_BUFFER_LENGTH_ERROR
  Else
    MQSETX Hconn, Hobj, SelectorCount, Selectors, intAttrCount, intAttrs, CharAttrLength, CharAttrs, CompCode, Reason
  End If
End Sub
