Attribute VB_Name = "CMQXB"
'**********************************************************************'
'*                                                                    *'
'*  Program name:  CMQXB                                              *'
'*                                                                    *'
'*  Description:   This file declares calls, structures, and          *'
'*                 constants for the IBM Message Queue Interface      *'
'*                 (MQI) in the Windows environment.                  *'
'*                                                                    *'
'*  Statement:     Licensed Materials - Property of IBM               *'
'*                                                                    *'
'*                 (C) Copyright IBM Corp. 1994, 1998                 *'
'*                                                                    *'
'*                 U.S. Government Users Restricted Rights -          *'
'*                 use, duplication or disclosure restricted by       *'
'*                 GSA ADP Schedule Contract with IBM Corp.           *'
'*                                                                    *'
'**********************************************************************'

'**********************************************************************'
'*  Values Related to MQCD Structure                                  *'
'**********************************************************************'

'Structure Version Number
Global Const MQCD_VERSION_1 = 1
Global Const MQCD_VERSION_2 = 2
Global Const MQCD_VERSION_3 = 3
Global Const MQCD_VERSION_4 = 4
Global Const MQCD_VERSION_5 = 5
Global Const MQCD_CURRENT_VERSION = 5

'Channel Type
Global Const MQCHT_SENDER = 1
Global Const MQCHT_SERVER = 2
Global Const MQCHT_RECEIVER = 3
Global Const MQCHT_REQUESTER = 4
Global Const MQCHT_ALL = 5
Global Const MQCHT_CLNTCONN = 6
Global Const MQCHT_SVRCONN = 7
Global Const MQCHT_CLUSRCVR = 8
Global Const MQCHT_CLUSSDR = 9

'Transport Type
Global Const MQXPT_LU62 = 1
Global Const MQXPT_TCP = 2
Global Const MQXPT_NETBIOS = 3
Global Const MQXPT_SPX = 4

'Put Authority
Global Const MQPA_DEFAULT = 1
Global Const MQPA_CONTEXT = 2

'Channel Data Conversion
Global Const MQCDC_SENDER_CONVERSION = 1
Global Const MQCDC_NO_SENDER_CONVERSION = 0

'MCA Type
Global Const MQMCAT_PROCESS = 1
Global Const MQMCAT_THREAD = 2

' NonPersistent-Message Speed
Global Const MQPMS_NORMAL = 1
Global Const MQPMS_FAST = 2

'Structure Length
Global Const MQCD_LENGTH_4 = 1536
Global Const MQCD_LENGTH_5 = 1552

'**********************************************************************'
'*  Values Related to MQCXP Structure                                 *'
'**********************************************************************'

'Structure Identifier
Global Const MQCXP_STRUC_ID = "CXP "

'Structure Version Number
Global Const MQCXP_VERSION_1 = 1
Global Const MQCXP_VERSION_2 = 2
Global Const MQCXP_VERSION_3 = 3
Global Const MQCXP_CURRENT_VERSION = 3

'Exit Response 2
Global Const MQXR2_PUT_WITH_DEF_ACTION = 0
Global Const MQXR2_PUT_WITH_DEF_USERID = 1
Global Const MQXR2_PUT_WITH_MSG_USERID = 2
Global Const MQXR2_USE_AGENT_BUFFER = 0
Global Const MQXR2_USE_EXIT_BUFFER = 4
Global Const MQXR2_CONTINUE_CHAIN = 8
Global Const MQXR2_SUPPRESS_CHAIN = 16

' Capability Flags
Global Const MQCF_NONE = 0
Global Const MQCF_DIST_LISTS = 1


'**********************************************************************'
'*  Values Related to MQDXP Structure                                 *'
'**********************************************************************'

'Structure Identifier
Global Const MQDXP_STRUC_ID = "DXP "

'Structure Version Number
Global Const MQDXP_VERSION_1 = 1

'Exit Response
Global Const MQXDR_OK = 0
Global Const MQXDR_CONVERSION_FAILED = 1


'**********************************************************************'
'*  General Values Related to Exits                                   *'
'**********************************************************************'

'Exit Identifier
Global Const MQXT_CHANNEL_SEC_EXIT = 11
Global Const MQXT_CHANNEL_MSG_EXIT = 12
Global Const MQXT_CHANNEL_SEND_EXIT = 13
Global Const MQXT_CHANNEL_RCV_EXIT = 14
Global Const MQXT_CHANNEL_MSG_RETRY_EXIT = 15
Global Const MQXT_CHANNEL_AUTO_DEF_EXIT = 16

'Exit Reason
Global Const MQXR_INIT = 11
Global Const MQXR_TERM = 12
Global Const MQXR_MSG = 13
Global Const MQXR_XMIT = 14
Global Const MQXR_SEC_MSG = 15
Global Const MQXR_INIT_SEC = 16
Global Const MQXR_RETRY = 17

'Exit Response
Global Const MQXCC_OK = 0
Global Const MQXCC_SUPPRESS_FUNCTION = -1
Global Const MQXCC_SEND_AND_REQUEST_SEC_MSG = -3
Global Const MQXCC_SEND_SEC_MSG = -4
Global Const MQXCC_SUPPRESS_EXIT = -5
Global Const MQXCC_CLOSE_CHANNEL = -6

'Exit User Area Value
Global MQXUA_NONE As String * 16               ' Initialise with default call


'**********************************************************************'
'*  Values Related to MQXCNVC Call                                    *'
'**********************************************************************'

'Conversion Options
Global Const MQDCC_DEFAULT_CONVERSION = &H1
Global Const MQDCC_SOURCE_ENC_NATIVE = &H20
Global Const MQDCC_SOURCE_ENC_NORMAL = &H10
Global Const MQDCC_SOURCE_ENC_REVERSED = &H20
Global Const MQDCC_SOURCE_END_UNDEFINED = &H0
Global Const MQDCC_TARGET_NATIVE = &H100
Global Const MQDCC_TARGET_NORMAL = &H100
Global Const MQDCC_TARGET_REVERSED = &H200
Global Const MQDCC_TARGET_UNDEFINED = &H0
Global Const MQDCC_NONE = 0

' Conversion Options Masks and Factors
Global Const MQDCC_SOURCE_ENC_MASK = &HF0
Global Const MQDCC_TARGET_ENC_MASK = &HF00
Global Const MQDCC_SOURCE_ENC_FACTOR = 16
Global Const MQDCC_TARGET_ENC_FACTOR = 256


'**********************************************************************'
'*  MQCD Structure -- Channel Definition                              *'
'**********************************************************************'

Type MQCD
  ChannelName           As String * 20   ' Channel definition name
  Version               As Long          ' Structure version number
  ChannelType           As Long          ' Channel type
  TransportType         As Long          ' Transport type
  Desc                  As String * 64   ' Channel description
  QMgrName              As String * 48   ' Queue-manager name
  XmitQName             As String * 48   ' Transmission queue name
  ShortConnectionName   As String * 20   ' First 20 characters of connection name
  MCAName               As String * 20   ' Reserved'
  ModeName              As String * 8    ' LU 6.2 Mode name'
  TpName                As String * 64   ' LU 6.2 transaction program name'
  BatchSize             As Long          ' Batch size'
  DiscInterval          As Long          ' Disconnect interval'
  ShortRetryCount       As Long          ' Short retry count'
  ShortRetryInterval    As Long          ' Short retry wait interval'
  LongRetryCount        As Long          ' Long retry count'
  LongRetryInterval     As Long          ' Long retry wait interval'
  SecurityExit          As String * 128  ' Channel security exit name'
  MsgExit               As String * 128  ' Channel message exit name'
  SendExit              As String * 128  ' Channel send exit name'
  ReceiveExit           As String * 128  ' Channel receive exit name'
  SeqNumberWrap         As Long          ' Highest allowable message sequence number'
  MaxMsgLength          As Long          ' Maximum message length'
  PutAuthority          As Long          ' Put authority'
  DataConversion        As Long          ' Data conversion'
  SecurityUserData      As String * 32   ' Channel security exit user data'
  MsgUserData           As String * 32   ' Channel message exit user data'
  SendUserData          As String * 32   ' Channel send exit user data'
  ReceiveUserData       As String * 32   ' Channel receive exit user data'
  UserIdentifier        As String * 12   ' User identifier'
  Password              As String * 12   ' Password'
  MCAUserIdentifier     As String * 12   ' Message channel agent user identifier'
  MCAType               As Long          ' Message channel agent type'
  ConnectionName        As String * 264  ' Connection name'
  RemoteUserIdentifier  As String * 12   ' User identifier from partner'
  RemotePassword        As String * 12   ' Password from partner'
  MsgRetryExit          As String * 128  ' Message-retry exit name'
  MsgRetryUserData      As String * 32   ' Message-retry exit user data'
  MsgRetryCount         As Long          ' Number of times MCA will try to put the'
                                        ' message, after the first attempt has'
                                        ' failed'
  MsgRetryInterval      As Long          ' Minimum interval in milliseconds after'
                                         ' which the open or put operation will be'
                                         ' retried'
  HeartbeatInterval     As Long          ' Time in seconds between heartbeat flows
  BatchInterval         As Long          ' Batch duration
  NonPersistentMsgSpeed As Long          ' Speed at which non-persistent messages are sent
  StrucLength           As Long          ' Length of MQCD structure
  ExitNameLength        As Long          ' Length of exit name
  ExitDataLength        As Long          ' Length of exit user data
  MsgExitsDefined       As Long          ' Number of message exits defined
  SendExitsDefined      As Long          ' Number of send exits defined
  ReceiveExitsDefined   As Long          ' Number of receive exits defined
  MsgExitPtr            As Long          ' Reserved
  MsgUserDataPtr        As Long          ' Reserved
  SendExitPtr           As Long          ' Reserved
  SendUserDataPtr       As Long          ' Reserved
  ReceiveExitPtr        As Long          ' Reserved
  ReceiveUserDataPtr    As Long          ' Reserved
  NetworkPriority       As Long          ' Network connection priority
  ClustersDefined       As Long          ' Number of clusters
  ClusterPtr            As Long          ' Reserved
End Type

Global MQCD_DEFAULT As MQCD

'**********************************************************************'
'*  MQCXP Structure -- Channel Exit Parameter                         *'
'**********************************************************************'

Type MQCXP
  StrucId          As String * 4  ' Structure identifier'
  Version          As Long        ' Structure version number'
  ExitId           As Long        ' Type of exit'
  ExitReason       As Long        ' Reason for invoking exit'
  ExitResponse     As Long        ' Response from exit'
  ExitResponse2    As Long        ' Secondary response from exit'
  Feedback         As Long        ' Feedback code'
  MaxSegmentLength As Long        ' Maximum segment length'
  ExitUserArea     As String * 16 ' Exit user area'
  ExitData         As String * 32 ' Exit data'
  MsgRetryCount    As Long        ' Number of times the message has been retried'
  MsgRetryInterval As Long        ' Minimum interval in milliseconds after which'
                                  ' the put operation should be retried'
  MsgRetryReason   As Long        ' Reason code from previous attempt to put the'
                                  ' message'
  HeaderLength     As Long        ' Length of header information
  PartnerName      As Long        ' Partner name
  FAPLevel         As Long        ' Negotiated FAP level
  CapabilityFlags  As Long        ' Capability flags
  ExitNumber       As Long        ' Exit number
End Type

Global MQCXP_DEFAULT As MQCXP

'**********************************************************************'
'*  MQDXP Structure -- Data-Conversion Exit Parameter                 *'
'**********************************************************************'

Type MQDXP
  StrucId        As String * 4 'Structure identifier'
  Version        As Long     'Structure version number'
  ExitOptions    As Long     'Reserved'
  AppOptions     As Long     'Application options'
  Encoding       As Long     'Encoding required by application'
  CodedCharSetId As Long     'Coded character-set identifier required by'
                             'application'
  DataLength     As Long     'Length in bytes of message data'
  CompCode       As Long     'Completion code'
  Reason         As Long     'Reason code qualifying CompCode'
  ExitResponse   As Long     'Response from exit'
  Hconn          As Long     'Connection handle'
End Type

Global MQDXP_DEFAULT As MQDXP


Sub MQCD_DEFAULTS(Struc As MQCD)
  Struc.ChannelName = ""
  Struc.Version = MQCD_VERSION_3
  Struc.ChannelType = MQCHT_SENDER
  Struc.TransportType = MQXPT_LU62
  Struc.Desc = ""
  Struc.QMgrName = ""
  Struc.XmitQName = ""
  Struc.ShortConnectionName = ""
  Struc.MCAName = ""
  Struc.ModeName = ""
  Struc.TpName = ""
  Struc.BatchSize = 50
  Struc.DiscInterval = 6000
  Struc.ShortRetryCount = 10
  Struc.ShortRetryInterval = 60
  Struc.LongRetryCount = 999999999
  Struc.LongRetryInterval = 1200
  Struc.SecurityExit = ""
  Struc.MsgExit = ""
  Struc.SendExit = ""
  Struc.ReceiveExit = ""
  Struc.SeqNumberWrap = 999999999
  Struc.MaxMsgLength = 4194304
  Struc.PutAuthority = MQPA_DEFAULT
  Struc.DataConversion = MQCDC_NO_SENDER_CONVERSION
  Struc.SecurityUserData = ""
  Struc.MsgUserData = ""
  Struc.SendUserData = ""
  Struc.ReceiveUserData = ""
  Struc.UserIdentifier = ""
  Struc.Password = ""
  Struc.MCAUserIdentifier = ""
  Struc.MCAType = MQMCAT_PROCESS
  Struc.ConnectionName = ""
  Struc.RemoteUserIdentifier = ""
  Struc.RemotePassword = ""
  Struc.MsgRetryExit = ""
  Struc.MsgRetryUserData = ""
  Struc.MsgRetryCount = 10
  Struc.MsgRetryInterval = 1000
  Struc.HeartbeatInterval = 300
  Struc.BatchInterval = 0
  Struc.NonPersistentMsgSpeed = MQNPMS_FAST
  Struc.StrucLength = MQCD_LENGTH_5
  Struc.ExitNameLength = MQ_EXIT_NAME_LENGTH
  Struc.ExitDataLength = MQ_EXIT_DATA_LENGTH
  Struc.MsgExitsDefined = 0
  Struc.SendExitsDefined = 0
  Struc.ReceiveExitsDefined = 0
  Struc.MsgExitPtr = 0
  Struc.MsgUserDataPtr = 0
  Struc.SendExitPtr = 0
  Struc.SendUserDataPtr = 0
  Struc.ReceiveExitPtr = 0
  Struc.ReceiveUserDataPtr = 0
  Struc.NetworkPriority = 0
  Struc.ClustersDefined = 0
  Struc.ClusterPtr = 0
End Sub


Sub MQCXP_DEFAULTS(Struc As MQCXP)
  Struc.StrucId = MQCXP_STRUC_ID
  Struc.Version = MQCXP_VERSION_2
  Struc.ExitId = 0
  Struc.ExitReason = 0
  Struc.ExitResponse = MQXCC_OK
  Struc.ExitResponse2 = MQXR2_PUT_WITH_DEF_ACTION
  Struc.Feedback = 0
  Struc.MaxSegmentLength = 0
  Struc.ExitUserArea = MQXUA_NONE
  Struc.ExitData = ""
  Struc.MsgRetryCount = 0
  Struc.MsgRetryInterval = 0
  Struc.MsgRetryReason = 0
  Struc.HeaderLength = 0
  Struc.PartnerName = ""
  Struc.FAPLevel = 0
  Struc.CapabilityFlags = MQCF_NONE
  Struc.ExitNumber = 1
End Sub

Sub MQDXP_DEFAULTS(Struc As MQDXP)
  Struc.StrucId = MQDXP_STRUC_ID
  Struc.Version = MQDXP_VERSION_1
  Struc.ExitOptions = 0
  Struc.AppOptions = 0
  Struc.Encoding = 0
  Struc.CodedCharSetId = 0
  Struc.DataLength = 0
  Struc.CompCode = MQCC_OK
  Struc.Reason = MQRC_NONE
  Struc.ExitResponse = MQXDR_CONVERSION_FAILED
  Struc.Hconn = 0
End Sub

Sub MQXB_DEFAULTS()
  ' Use to set defaults
  MQCD_DEFAULTS MQCD_DEFAULT
  MQCXP_DEFAULTS MQCXP_DEFAULT
  MQDXP_DEFAULTS MQDXP_DEFAULT

  MQXUA_NONE = String(16, 0)
End Sub
